@@ -75,6 +75,11 @@ int cinmaxchan = 0;
 int clatency = HIGH_LATENCY_DRIVER;
 char * cinname = NULL;
 
+int reentrant = 0;
+int creentrant = 0;
+int nomain = 0;
+int adebug = 0;
+
 char * session = NULL;
 char * sessionkey = NULL;
 int feclevel = FEC_STANDARD;
@@ -87,6 +92,16 @@ unsigned short sip_port = SIP_RTP_PORT;
 char sip_ip[16] = SIP_IP;
 int msession_interval = MSESSION_INTERVAL;
 
+char * au_component_type = NULL;
+char * au_component_manu = NULL;
+char * au_component_subtype = NULL;
+char * au_filesystem_name = NULL;
+char * au_ui_name = NULL;
+char * au_ui_manu = NULL;
+char * au_manu_url = NULL;
+char * au_view_bundlename = NULL;
+char * au_view_baseclass = NULL;
+
 int timeoptions = UNKNOWN;
 float latency = -1.0F;
 int catchsignals = 0;
@@ -119,6 +134,7 @@ int constoptimize = 1;
 
 int srate = -1;
 int krate = -1;
+int saol_krate = -1;
 int twocycle = -1;
 int inchannels = -1;
 int outchannels = -1;
@@ -126,8 +142,8 @@ int interp = -1;
 float globaltune = 440.0;
 
 int interp_cmdline = -1;
-unsigned long sinc_pilen = 128;
-unsigned long sinc_zcross = 3;
+unsigned int sinc_pilen = 128;
+unsigned int sinc_zcross = 3;
 float sinc_upmax = 4.0F;
 
 tnode  * troot = NULL;
@@ -239,10 +255,10 @@ int midiallsoundsoff = 0;       /* uses the MIDI all sounds off command */
 
                                 /* temporary midi variables */
 
-unsigned long midictime = 0;    /* current time (during parse) */
+unsigned int midictime = 0;    /* current time (during parse) */
 unsigned char midirunstat = 0;  /* running status for streaming MIDI */
 
-long midiext[MCHAN];
+int midiext[MCHAN];
 unsigned int midibank[MCHAN];   /* note state for each note/chan */
 int midifirst[MCHAN];           /* flags first event in new channel */
 tnode * midicurrinstr[MCHAN];   /* current instr for each channel */
@@ -262,7 +278,7 @@ unsigned char bitstoread = 0;   /* buffers for mp4 binary read */
 int bitreadpos = -1;            /* keeps track of bit position */
                                 
                                 /* for mp4 binary intrachunk read */
-unsigned long bitreadlen = 0;   /* number of bytes left in chunk */
+unsigned int bitreadlen = 0;   /* number of bytes left in chunk */
 int bitscoretype = 0;           /* type of line read in progress */
 int bitlinecount = 0;           /* score line finished */
 float bitscotime = 0;           /* score time */
