@@ -143,8 +143,8 @@ UInt32 asysi_buffchan[ASYSI_MAXSTREAM];    /* per-stream channels  */
 #if (defined(ASYS_ACTIVE_IO) && !defined(ASYS_HASINPUT))
 
 ASYS_ITYPE * asysn_coreaudio_ibuf;
-long asysn_coreaudio_ilast;
-long asysn_coreaudio_iptr;
+int asysn_coreaudio_ilast;
+int asysn_coreaudio_iptr;
 #endif
 
 /* state for passive output driver */
@@ -152,8 +152,8 @@ long asysn_coreaudio_iptr;
 #if (defined(ASYS_ACTIVE_IO) && !defined(ASYS_HASOUTPUT))
 
 ASYS_OTYPE * asysn_coreaudio_obuf;
-long asysn_coreaudio_optr;
-long asysn_coreaudio_olast;
+int asysn_coreaudio_optr;
+int asysn_coreaudio_olast;
 #endif
 
 int asysn_coreaudio_instatus;        /* code coreaudio input info   */
@@ -174,7 +174,7 @@ int asysn_coreaudio_pipepair[2];    /* asys_main/IOProc comm chan  */
 int volatile asysn_coreaudio_live;  /* routes silence or SA to out */
 int asysn_coreaudio_silentframes;   /* leader-tape length          */
 
-long volatile asysn_coreaudio_touch; /* for page warmups           */
+int volatile asysn_coreaudio_touch; /* for page warmups           */
 UInt64 asysn_coreaudio_ksync_then;   /* counter for time spent     */
 
 /*~~~~~~~~~~~~~~~~~*/
@@ -202,54 +202,53 @@ int asys_mac_orun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff, UInt32 f
   int frameidx = 0;
   int busidx, chanidx, buffidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while (frameidx < frames)
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx]=0.0F;
+	memset(&(TB(0)), 0, sizeof(float)*ENDBUS);
 	main_apass();
 
 #if (ASYS_OCHAN == 1L)   /* mono case */
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
-	    *((obuff[buffidx])++) = bus[BUS_output_bus];
+	    *((obuff[buffidx])++) = TB(BUS_output_bus);
 #else
 	busidx = BUS_output_bus;
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
 	    {
 	      if (busidx < ENDBUS_output_bus)
-		*(obuff[buffidx]) = bus[busidx++];
+		*(obuff[buffidx]) = TB(busidx++);
 	      (obuff[buffidx])++;
 	    }
 #endif
 
-	acycleidx++;
+	EV(acycleidx)++;
 	frameidx++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
-	  return (asys_exit_status = ASYS_EXIT);
+	if (EV(kcycleidx) > EV(endkcycle))
+	  return (EV(asys_exit_status) = ASYS_EXIT);
 
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
 	main_ipass();
-	pass = KPASS;
+	EV(pass) = KPASS;
 	main_control();
 	if (main_kpass())
-	  return (asys_exit_status = ASYS_EXIT);
-	pass = APASS;
+	  return (EV(asys_exit_status) = ASYS_EXIT);
+	EV(pass) = APASS;
       }
 
   return ASYS_DONE;
@@ -272,14 +271,13 @@ int asys_mac_iorun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff,
   int mono_in = ((inumbuff == 1) && (ibuffchan[0] == 1));
   int busidx, chanidx, buffidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while (frameidx < frames)
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx]=0.0F;
+	memset(&(TB(0)), 0, sizeof(float)*ENDBUS);
 
 	if (!mono_in)
 	  {
@@ -288,14 +286,14 @@ int asys_mac_iorun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff,
 	      for (chanidx = 0; chanidx < ibuffchan[buffidx]; chanidx++)
 		{
 		  if (busidx < ENDBUS_input_bus)
-		    bus[busidx++] = *(ibuff[buffidx]);
+		    TB(busidx++) = *(ibuff[buffidx]);
 		  (ibuff[buffidx])++;
 		}
 	  }
 	else
 	  {
 	    for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	      bus[busidx] = *(ibuff[0]);
+	      TB(busidx) = *(ibuff[0]);
 	    (ibuff[0])++;
 	  }
 
@@ -304,41 +302,41 @@ int asys_mac_iorun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff,
 #if (ASYS_OCHAN == 1L)   /* mono case */
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
-	    *((obuff[buffidx])++) = bus[BUS_output_bus];
+	    *((obuff[buffidx])++) = TB(BUS_output_bus);
 #else
 	busidx = BUS_output_bus;
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
 	    {
 	      if (busidx < ENDBUS_output_bus)
-		*(obuff[buffidx]) = bus[busidx++];
+		*(obuff[buffidx]) = TB(busidx++);
 	      (obuff[buffidx])++;
 	    }
 #endif
 
-	acycleidx++;
+	EV(acycleidx)++;
 	frameidx++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
-	  return (asys_exit_status = ASYS_EXIT);
+	if (EV(kcycleidx) > EV(endkcycle))
+	  return (EV(asys_exit_status) = ASYS_EXIT);
 
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
 	main_ipass();
-	pass = KPASS;
+	EV(pass) = KPASS;
 	main_control();
 	if (main_kpass())
-	  return (asys_exit_status = ASYS_EXIT);
-	pass = APASS;
+	  return (EV(asys_exit_status) = ASYS_EXIT);
+	EV(pass) = APASS;
       }
 
   return ASYS_DONE;
@@ -359,31 +357,30 @@ int asys_mac_orun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff,
   int frameidx = 0;
   int busidx, chanidx, buffidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while (frameidx < frames)
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx]=0.0F;
+	memset(&(TB(0)), 0, sizeof(float)*ENDBUS);
 
 	if (asysn_coreaudio_ilast == asysn_coreaudio_iptr)
 	  {  
 	    if ((asys_getbuf(&asysn_coreaudio_ibuf, &asysn_coreaudio_ilast) 
 		 != ASYS_DONE) || (asysn_coreaudio_ilast == 0))
-	      return (asys_exit_status = ASYS_EXIT);
+	      return (EV(asys_exit_status) = ASYS_EXIT);
 	    asysn_coreaudio_iptr = 0;
 	  }
 
 #if (ASYS_ITYPENAME == ASYS_SHORT)
 	for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	  bus[busidx] = 3.051851e-5F*asysn_coreaudio_ibuf[asysn_coreaudio_iptr++];
+	  TB(busidx) = 3.051851e-5F*asysn_coreaudio_ibuf[asysn_coreaudio_iptr++];
 #endif
 
 #if (ASYS_ITYPENAME == ASYS_FLOAT)
 	for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	  bus[busidx] = asysn_coreaudio_ibuf[asysn_coreaudio_iptr++];
+	  TB(busidx) = asysn_coreaudio_ibuf[asysn_coreaudio_iptr++];
 #endif
 
 	main_apass();
@@ -391,41 +388,41 @@ int asys_mac_orun(float * obuff[], UInt32 obuffchan[], UInt32 onumbuff,
 #if (ASYS_OCHAN == 1L)   /* mono case */
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
-	    *((obuff[buffidx])++) = bus[BUS_output_bus];
+	    *((obuff[buffidx])++) = TB(BUS_output_bus);
 #else
 	busidx = BUS_output_bus;
 	for (buffidx = 0; buffidx < onumbuff; buffidx++)
 	  for (chanidx = 0; chanidx < obuffchan[buffidx]; chanidx++)
 	    {
 	      if (busidx < ENDBUS_output_bus)
-		*(obuff[buffidx]) = bus[busidx++];
+		*(obuff[buffidx]) = TB(busidx++);
 	      (obuff[buffidx])++;
 	    }
 #endif
 
-	acycleidx++;
+	EV(acycleidx)++;
 	frameidx++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
-	  return (asys_exit_status = ASYS_EXIT);
+	if (EV(kcycleidx) > EV(endkcycle))
+	  return (EV(asys_exit_status) = ASYS_EXIT);
 
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
 	main_ipass();
-	pass = KPASS;
+	EV(pass) = KPASS;
 	main_control();
 	if (main_kpass())
-	  return (asys_exit_status = ASYS_EXIT);
-	pass = APASS;
+	  return (EV(asys_exit_status) = ASYS_EXIT);
+	EV(pass) = APASS;
       }
 
   return ASYS_DONE;
@@ -447,14 +444,13 @@ int asys_mac_irun(float * ibuff[], UInt32 ibuffchan[], UInt32 inumbuff,
   int mono_in = ((inumbuff == 1) && (ibuffchan[0] == 1));
   int busidx, chanidx, buffidx;
 
-  if (asys_exit_status == ASYS_EXIT)
+  if (EV(asys_exit_status) == ASYS_EXIT)
     return ASYS_EXIT;
 
   while (frameidx < frames)
-    if (acycleidx < ACYCLE)
+    if (EV(acycleidx) < EV(ACYCLE))
       {
-	for (busidx=0; busidx<ENDBUS;busidx++)
-	  bus[busidx]=0.0F;
+	memset(&(TB(0)), 0, sizeof(float)*ENDBUS);
 
 	if (!mono_in)
 	  {
@@ -463,14 +459,14 @@ int asys_mac_irun(float * ibuff[], UInt32 ibuffchan[], UInt32 inumbuff,
 	      for (chanidx = 0; chanidx < ibuffchan[buffidx]; chanidx++)
 		{
 		  if (busidx < ENDBUS_input_bus)
-		    bus[busidx++] = *(ibuff[buffidx]);
+		    TB(busidx++) = *(ibuff[buffidx]);
 		  (ibuff[buffidx])++;
 		}
 	  }
 	else
 	  {
 	    for(busidx=BUS_input_bus;busidx<ENDBUS_input_bus;busidx++)
-	      bus[busidx] = *(ibuff[0]);
+	      TB(busidx) = *(ibuff[0]);
 	    (ibuff[0])++;
 	  }
 
@@ -478,11 +474,11 @@ int asys_mac_irun(float * ibuff[], UInt32 ibuffchan[], UInt32 inumbuff,
 
 #if (ASYS_OTYPENAME == ASYS_FLOAT)
 	for (busidx = BUS_output_bus; busidx < ENDBUS_output_bus; busidx++)
-	  if ((bus[busidx] <= 1.0F) && (bus[busidx] >= -1.0F))
-	    asysn_coreaudio_obuf[asysn_coreaudio_optr++] = bus[busidx];
+	  if ((TB(busidx) <= 1.0F) && (TB(busidx) >= -1.0F))
+	    asysn_coreaudio_obuf[asysn_coreaudio_optr++] = TB(busidx);
 	  else
 	    {
-	      if (bus[busidx] > 0.0F)
+	      if (TB(busidx) > 0.0F)
 		asysn_coreaudio_obuf[asysn_coreaudio_optr++] = 1.0F;
 	      else
 		asysn_coreaudio_obuf[asysn_coreaudio_optr++] = -1.0F;
@@ -491,11 +487,11 @@ int asys_mac_irun(float * ibuff[], UInt32 ibuffchan[], UInt32 inumbuff,
 
 #if (ASYS_OTYPENAME == ASYS_SHORT)
 	for (busidx = BUS_output_bus; busidx < ENDBUS_output_bus; busidx++)
-	  if ((bus[busidx] <= 1.0F) && (bus[busidx] >= -1.0F))
-	    asysn_coreaudio_obuf[asysn_coreaudio_optr++] = ((float)0x7FFF)*bus[busidx];
+	  if ((TB(busidx) <= 1.0F) && (TB(busidx) >= -1.0F))
+	    asysn_coreaudio_obuf[asysn_coreaudio_optr++] = ((float)0x7FFF)*TB(busidx);
 	  else
 	    {
-	      if (bus[busidx] > 0.0F)
+	      if (TB(busidx) > 0.0F)
 		asysn_coreaudio_obuf[asysn_coreaudio_optr++] = 0x7FFF;
 	      else
 		asysn_coreaudio_obuf[asysn_coreaudio_optr++] = 0xFFFF;
@@ -507,39 +503,39 @@ int asys_mac_irun(float * ibuff[], UInt32 ibuffchan[], UInt32 inumbuff,
 	    if (asys_putbuf(&asysn_coreaudio_obuf,&asysn_coreaudio_olast)==ASYS_DONE)
 	      asysn_coreaudio_optr = 0;
 	    else
-	      return (asys_exit_status = ASYS_EXIT);
+	      return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
 
-	acycleidx++;
+	EV(acycleidx)++;
 	frameidx++;
       }
     else
       {
-	acycleidx = 0;
-	if (pass == APASS)
+	EV(acycleidx) = 0;
+	if (EV(pass) == APASS)
 	  {      
-	    cpuload = ksync();
-	    kcycleidx++;
+	    EV(cpuload) = ksync();
+	    EV(kcycleidx)++;
 	  }
-	if (kcycleidx > endkcycle)
+	if (EV(kcycleidx) > EV(endkcycle))
 	  {
 	    if (asysn_coreaudio_optr)
 	      asys_putbuf(&asysn_coreaudio_obuf, &asysn_coreaudio_optr);
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = IPASS;
-	scorebeats = scoremult*(kcycleidx - kbase) + scorebase;
-	absolutetime = (kcycleidx - 1)*KTIME;
+	EV(pass) = IPASS;
+	EV(scorebeats) = EV(scoremult)*(EV(kcycleidx) - EV(kbase)) + EV(scorebase);
+	EV(absolutetime) = (EV(kcycleidx) - 1)*EV(KTIME);
 	main_ipass();
-	pass = KPASS;
+	EV(pass) = KPASS;
 	main_control();
 	if (main_kpass())
 	  {
 	    if (asysn_coreaudio_optr)
 	      asys_putbuf(&asysn_coreaudio_obuf, &asysn_coreaudio_optr);
-	    return (asys_exit_status = ASYS_EXIT);
+	    return (EV(asys_exit_status) = ASYS_EXIT);
 	  }
-	pass = APASS;
+	EV(pass) = APASS;
       }
 
   return ASYS_DONE;
@@ -859,7 +855,7 @@ void asysn_coreaudio_page()
   /**********************************/
 
   for (addrtop = touchtop*psize; addrtop >= psize; addrtop -= psize)
-    asysn_coreaudio_touch ^= *((long *) addrtop);
+    asysn_coreaudio_touch ^= *((int *) addrtop);
 
   /******************************/
   /* attempt to do page locking */
@@ -1219,7 +1215,7 @@ int asysn_coreaudio_streaminfo(AudioDeviceID aid, Boolean input,
 /********************************************************************/
 
 int asysn_coreaudio_reconfigure(AudioDeviceID aid, Boolean input, 
-				long srate, double * core_srate)
+				int srate, double * core_srate)
 
 {
   AudioStreamBasicDescription desc;
@@ -1478,8 +1474,8 @@ int asysn_coreaudio_shutdown_dlisten(AudioDeviceID aid, int input)
 /* coreaudio audio output only: ASYS_ACTIVE_O + one ASYS_ACTIVE_IO  */
 /********************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-		char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+		char * oname, int toption)
 
 {
   Float64 core_srate;
@@ -1541,8 +1537,8 @@ int asys_osetup(long srate, long ochannels, long osample,
 /* coreaudio audio input only: an ASYS_ACTIVE_IO case           */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-		char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+		char * iname, int toption)
 
 {
   UInt32 in_numchan, in_numstreams;
@@ -1604,9 +1600,9 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   coreaudio input and output: an ASYS_ACTIVE_IO case         */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-		 long isample, long osample, 
-		 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+		 int isample, int osample, 
+		 char * iname, char * oname, int toption)
 {
   UInt32 in_numchan, out_numchan, in_numstreams, out_numstreams;
   Float64 in_srate, out_srate;
@@ -1859,7 +1855,7 @@ void ksyncinit()
 
 {
   asysn_coreaudio_ksync_then = 0;
-  asysn_coreaudio_ksync_normal = (float) (KRATE/AudioGetHostClockFrequency());
+  asysn_coreaudio_ksync_normal = (float) (EV(KRATE)/AudioGetHostClockFrequency());
 }
 
 /***********************************************************/
