@@ -81,17 +81,17 @@ DSBUFFERDESC		dsbdesc;
 DSCAPS				dscaps;
 DSBCAPS				pr,sec;
 HRESULT       		hr;	
-unsigned long		ds_numofsubbuff;
-unsigned long		ds_subbuffercounter=0;
-unsigned long		ds_writeposition=0;
-unsigned long		ds_counter=0;
-unsigned long		ds_resetwritecrspoint=0;
-unsigned long		SECBUFFBYTESIZE;
-unsigned long		SUBBUFFBYTESIZE;
-unsigned long		SUBBUFFSAMPLESIZE;
-unsigned long		WRITEPOSITIONOFFSET;
-unsigned long		TIMES;
-unsigned long		EXCEPTIONTIMES;
+unsigned int		ds_numofsubbuff;
+unsigned int		ds_subbuffercounter=0;
+unsigned int		ds_writeposition=0;
+unsigned int		ds_counter=0;
+unsigned int		ds_resetwritecrspoint=0;
+unsigned int		SECBUFFBYTESIZE;
+unsigned int		SUBBUFFBYTESIZE;
+unsigned int		SUBBUFFSAMPLESIZE;
+unsigned int		WRITEPOSITIONOFFSET;
+unsigned int		TIMES;
+unsigned int		EXCEPTIONTIMES;
  
   
 void DevCaps(DSCAPS *);
@@ -101,7 +101,7 @@ void WaitForNotification();
 void Close();
 void Play();
 void Stop();
-int InitOutput(unsigned long);
+int InitOutput(unsigned int);
  
 void DevCaps(DSCAPS *DSCaps)
 {	
@@ -147,9 +147,9 @@ void Stop()
 }
  
  
-int InitOutput(unsigned long sys_osize, 
-			   unsigned long samplerate, 
-			   unsigned long numchannels)
+int InitOutput(unsigned int sys_osize, 
+			   unsigned int samplerate, 
+			   unsigned int numchannels)
 { 
 	HWND hwnd = GetForegroundWindow();
 	if(hwnd==NULL)hwnd = GetDesktopWindow();
@@ -256,11 +256,11 @@ int InitOutput(unsigned long sys_osize,
 /* Opens waveform output for a given srate/channels.
  */
  
-int asys_osetup(long srate, long ochannels, long osample, 
-                char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+                char * oname, int toption)
 {
 
-  long osize = ASYS_OCHAN*ACYCLE;
+  int osize = ASYS_OCHAN*ACYCLE;
 
   InitOutput(osize,srate,ochannels);
   return ASYS_SUCCESS;
@@ -285,7 +285,7 @@ void asys_oshutdown(void)
  
 #if defined(ASYS_HASOUTPUT)
  
-int asys_putbuf(short **buffer, long * osize)
+int asys_putbuf(short **buffer, int * osize)
  
 { 	
 	DWORD dwBytes;
@@ -309,7 +309,7 @@ int asys_putbuf(short **buffer, long * osize)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int i;
@@ -350,8 +350,8 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 
 /* Initializes audio input.
  */
-int asys_isetup(long srate, long ichannels, long isample, 
-                char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+                char * iname, int toption)
 
 {
   return ASYS_ERROR;
@@ -362,9 +362,9 @@ int asys_isetup(long srate, long ichannels, long isample,
 #if (defined(ASYS_HASOUTPUT) && defined(ASYS_HASINPUT))
 
 /* Initialized bidirectional audio flows. */
-int asys_iosetup(long srate, long ichannels, long ochannels,
-                 long isample, long osample, 
-                 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+                 int isample, int osample, 
+                 char * iname, char * oname, int toption)
 
 {
   return ASYS_ERROR;
@@ -389,7 +389,7 @@ void asys_ishutdown(void)
 /* Gets one frame of audio from input.
  */
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 {
   return ASYS_ERROR;
 }
@@ -411,7 +411,7 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
 #include <mmsystem.h>
 
 #define SYNC_MAXCOUNT 4294967296L
-#define SYNC_KMTIME KUTIME/1000
+#define SYNC_KMTIME EV(KUTIME)/1000
 
 DWORD sync_last, sync_this, sync_delay;
 TIMECAPS sync_tc;
@@ -495,7 +495,7 @@ void ksyncinit()
 #include <mmsystem.h>
 
 #define SYNC_MAXCOUNT 4294967296L
-#define SYNC_KMTIME KUTIME/1000
+#define SYNC_KMTIME EV(KUTIME)/1000
 
 DWORD sync_last, sync_this, sync_delay;
 TIMECAPS sync_tc;
