@@ -142,7 +142,7 @@
 #define ASYSIO_SYNC_WAITING    1
 #define ASYSIO_SYNC_SCHEDOTHER 2
 #else
-#define ASYSIO_MAXBLOCK ((int)KRATE)*2  /* max wait tor let SCHED_OTHERs run */
+#define ASYSIO_MAXBLOCK ((int)EV(KRATE))*2  /* max wait tor let SCHED_OTHERs run */
 #endif
 
 #endif
@@ -152,13 +152,13 @@
 /************************/
 
 int  asysio_fd;                    /* device pointer */
-long asysio_srate;                 /* sampling rate */
-long asysio_channels;              /* number of channels */
-long asysio_size;                  /* # samples in a buffer */
-long asysio_bsize;                 /* actual # bytes in a buffer */            
-long asysio_requested_bsize;       /* requested # bytes in a buffer */        
-long asysio_input;                 /* 1 if ASYSIO */
-long asysio_blocktime;             /* time (in bytes) blocked in kcycle */
+int asysio_srate;                 /* sampling rate */
+int asysio_channels;              /* number of channels */
+int asysio_size;                  /* # samples in a buffer */
+int asysio_bsize;                 /* actual # bytes in a buffer */            
+int asysio_requested_bsize;       /* requested # bytes in a buffer */        
+int asysio_input;                 /* 1 if ASYSIO */
+int asysio_blocktime;             /* time (in bytes) blocked in kcycle */
 
 struct count_info asysio_ptr;      /* for GET{I,O}*PTR  ioctl calls */
 struct audio_buf_info asysio_info; /* for GET{I,O}SPACE ioctl calls */
@@ -649,10 +649,10 @@ int asysio_screenwriter(void)
 /*        setup operations common to input and output           */
 /****************************************************************/
 
-int asysio_setup(long srate, long channels, int dir, int toption)
+int asysio_setup(int srate, int channels, int dir, int toption)
 
 {
-  long i, j, maxfrag;
+  int i, j, maxfrag;
 
   /******************/
   /* open soundcard */
@@ -785,8 +785,8 @@ int asysio_setup(long srate, long channels, int dir, int toption)
 /*        sets up audio output for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-                char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+                char * oname, int toption)
 
 {
   if (asysio_setup(srate, ochannels, ASYSIO_O, toption) == ASYS_ERROR)
@@ -807,8 +807,8 @@ int asys_osetup(long srate, long ochannels, long osample,
 /*        sets up audio input for a given srate/channels       */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-                char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+                char * iname, int toption)
 
 {
   if (asysio_setup(srate, ichannels, ASYSIO_I, toption) == ASYS_ERROR)
@@ -828,9 +828,9 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   sets up audio input and output for a given srate/channels  */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-                 long isample, long osample, 
-                 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+                 int isample, int osample, 
+                 char * iname, char * oname, int toption)
 
 
 {
@@ -865,11 +865,11 @@ int asys_iosetup(long srate, long ichannels, long ochannels,
 /*               gets one frame of audio from input             */
 /****************************************************************/
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 
 {
-  long diffcompute, starttime;
-  long size, recv, bptr, retry;
+  int diffcompute, starttime;
+  int size, recv, bptr, retry;
 
   *isize = asysio_size;
 
@@ -932,12 +932,12 @@ int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_putbuf(ASYS_OTYPE * asys_obuf[], int * osize)
 
 
 {
-  long size, sent, bptr, retry;
-  long diffcompute, starttime;
+  int size, sent, bptr, retry;
+  int diffcompute, starttime;
 
   size = (*osize)*2;
 
@@ -1001,7 +1001,7 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int i;
@@ -1024,7 +1024,7 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 int asysio_recover(void)
 
 {
-  long size, recv, bptr, retry;
+  int size, recv, bptr, retry;
   int i;
 
   asysio_reset = 0;
@@ -1067,7 +1067,7 @@ int asysio_recover(void)
     }
 
   ibusidx = 0;
-  if (asys_getbuf(&asys_ibuf, &asys_isize)==ASYS_ERROR)
+  if (asys_getbuf(&asys_ibuf, &EV(asys_isize))==ASYS_ERROR)
     return ASYS_ERROR;
 
 #endif
@@ -1147,7 +1147,7 @@ float ksync()
 
 {
   float ret;
-  long comptime;
+  int comptime;
 
   if (asysio_reset)
     {
@@ -1222,7 +1222,7 @@ float ksync()
 
 {
   float ret;
-  long comptime;
+  int comptime;
 
   if (!asysio_reset)
     {
