@@ -47,7 +47,7 @@
 /* global variables, must start with asys_ */
 
 ALport asyso_port;	/* audio port */
-long asyso_size;	/* number of samples in a buffer */
+int asyso_size;	/* number of samples in a buffer */
 short *asyso_buf;	/* output buffer */
 int asyso_channels;	/* number of channels */
 
@@ -58,7 +58,7 @@ int asyso_channels;	/* number of channels */
 /* global variables, must start with asys_ */
 
 ALport asysi_port;	/* audio port */
-long asysi_size;	/* number of samples in a buffer */
+int asysi_size;	/* number of samples in a buffer */
 short *asysi_buf;	/* input buffer */
 int asysi_channels;	/* number of channels */
 
@@ -88,7 +88,7 @@ static int setrate (ALport port, double rate)
 /*        core routine for audio output setup                   */
 /****************************************************************/
 
-int asyso_setup (long srate, long ochannels, long osize, char *oname)
+int asyso_setup (int srate, int ochannels, int osize, char *oname)
 {
 	ALconfig	config;
 
@@ -121,7 +121,7 @@ int asyso_setup (long srate, long ochannels, long osize, char *oname)
 /*        core routine for audio input setup                   */
 /****************************************************************/
 
-int asysi_setup(long srate, long ichannels, long isize, char *iname)
+int asysi_setup(int srate, int ichannels, int isize, char *iname)
 {
 	ALconfig	config;
 
@@ -154,8 +154,8 @@ int asysi_setup(long srate, long ichannels, long isize, char *iname)
 /*        sets up audio output for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup (long srate, long ochannels, long osample,
-	char *oname, long toption)
+int asys_osetup (int srate, int ochannels, int osample,
+	char *oname, int toption)
 {
 	return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
 }
@@ -169,8 +169,8 @@ int asys_osetup (long srate, long ochannels, long osample,
 /*        sets up audio input for a given srate/channels       */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample,
-	char *iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample,
+	char *iname, int toption)
 {
 	return asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname);
 }
@@ -184,9 +184,9 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   sets up audio input and output for a given srate/channels  */
 /****************************************************************/
 
-int asys_iosetup (long srate, long ichannels, long ochannels,
-	long isample, long osample,
-	char *iname, char *oname, long toption)
+int asys_iosetup (int srate, int ichannels, int ochannels,
+	int isample, int osample,
+	char *iname, char *oname, int toption)
 {
 	int	result;
 
@@ -253,7 +253,7 @@ void asys_ioshutdown(void)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble (ASYS_OTYPE *asys_obuf[], long *osize)
+int asys_preamble (ASYS_OTYPE *asys_obuf[], int *osize)
 
 {
 	*asys_obuf = asyso_buf;
@@ -268,7 +268,7 @@ int asys_preamble (ASYS_OTYPE *asys_obuf[], long *osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf (ASYS_OTYPE *asys_obuf[], long *osize)
+int asys_putbuf (ASYS_OTYPE *asys_obuf[], int *osize)
 {
 	*osize = asyso_size;
 
@@ -285,7 +285,7 @@ int asys_putbuf (ASYS_OTYPE *asys_obuf[], long *osize)
 /*               gets one frame of audio from input             */
 /****************************************************************/
 
-int asys_getbuf (ASYS_ITYPE *asys_ibuf[], long *isize)
+int asys_getbuf (ASYS_ITYPE *asys_ibuf[], int *isize)
 {
 	if (*asys_ibuf == NULL)
 		*asys_ibuf = asysi_buf;
