@@ -53,10 +53,10 @@
 
 FILE * asyso_fd;     /* output file pointer */
 char * asyso_name;   /* name of file  */        
-long asyso_srate;    /* sampling rate */
-long asyso_channels; /* number of channels */
-long asyso_size;    /* number of samples in a buffer */
-long asyso_nsamp;    /* total number of samples written */
+int asyso_srate;    /* sampling rate */
+int asyso_channels; /* number of channels */
+int asyso_size;    /* number of samples in a buffer */
+int asyso_nsamp;    /* total number of samples written */
 short * asyso_buf;   /* output buffer */
 
 #endif
@@ -67,10 +67,10 @@ short * asyso_buf;   /* output buffer */
 
 FILE * asysi_fd;     /* input file pointer */
 char * asysi_name;   /* name of file  */        
-long asysi_srate;    /* sampling rate */
-long asysi_channels; /* number of channels */
-long asysi_size;  /* number of samples in a buffer */
-long asysi_nsamp;    /* total number of samples written */
+int asysi_srate;    /* sampling rate */
+int asysi_channels; /* number of channels */
+int asysi_size;  /* number of samples in a buffer */
+int asysi_nsamp;    /* total number of samples written */
 short * asysi_buf;   /* output buffer */
 
 #endif
@@ -81,7 +81,7 @@ short * asysi_buf;   /* output buffer */
 /*        core routine for audio output setup                   */
 /****************************************************************/
 
-int asyso_setup(long srate, long ochannels, long osize, char * oname)
+int asyso_setup(int srate, int ochannels, int osize, char * oname)
 
 {
   asyso_name = strcpy((char *) calloc(7, sizeof(char)), "stdout");
@@ -102,7 +102,7 @@ int asyso_setup(long srate, long ochannels, long osize, char * oname)
 /*        core routine for audio input setup                   */
 /****************************************************************/
 
-int asysi_setup(long srate, long ichannels, long isize, char * iname)
+int asysi_setup(int srate, int ichannels, int isize, char * iname)
 
 {
   asysi_name = strcpy((char *) calloc(6, sizeof(char)), "stdin");
@@ -123,12 +123,12 @@ int asysi_setup(long srate, long ichannels, long isize, char * iname)
 /*        sets up audio output for a given srate/channels       */
 /****************************************************************/
 
-int asys_osetup(long srate, long ochannels, long osample, 
-                char * oname, long toption)
+int asys_osetup(int srate, int ochannels, int osample, 
+                char * oname, int toption)
 
 
 {
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 }
 
 #endif
@@ -140,11 +140,11 @@ int asys_osetup(long srate, long ochannels, long osample,
 /*        sets up audio input for a given srate/channels       */
 /****************************************************************/
 
-int asys_isetup(long srate, long ichannels, long isample, 
-                char * iname, long toption)
+int asys_isetup(int srate, int ichannels, int isample, 
+                char * iname, int toption)
 
 {
-  return asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname);
+  return asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname);
 }
 
 #endif
@@ -156,15 +156,15 @@ int asys_isetup(long srate, long ichannels, long isample,
 /*   sets up audio input and output for a given srate/channels  */
 /****************************************************************/
 
-int asys_iosetup(long srate, long ichannels, long ochannels,
-                 long isample, long osample, 
-                 char * iname, char * oname, long toption)
+int asys_iosetup(int srate, int ichannels, int ochannels,
+                 int isample, int osample, 
+                 char * iname, char * oname, int toption)
 
 {
 
-  if (asysi_setup(srate, ichannels, ASYS_ICHAN*ACYCLE, iname) != ASYS_DONE)
+  if (asysi_setup(srate, ichannels, ASYS_ICHAN*EV(ACYCLE), iname) != ASYS_DONE)
     return ASYS_ERROR;
-  return asyso_setup(srate, ochannels, ASYS_OCHAN*ACYCLE, oname);
+  return asyso_setup(srate, ochannels, ASYS_OCHAN*EV(ACYCLE), oname);
 
 }
 
@@ -268,7 +268,7 @@ void asys_ioshutdown(void)
 /*        creates buffer, and generates starting silence        */
 /****************************************************************/
 
-int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_preamble(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   int i;
@@ -283,7 +283,7 @@ int asys_preamble(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
+int asys_putbuf(ASYS_OTYPE * asys_obuf[], int * osize)
 
 {
   if (rwrite(*asys_obuf, sizeof(short), *osize, asyso_fd) != *osize)
@@ -301,12 +301,12 @@ int asys_putbuf(ASYS_OTYPE * asys_obuf[], long * osize)
 /*               sends one frame of audio to output             */
 /****************************************************************/
 
-int asys_getbuf(ASYS_ITYPE * asys_ibuf[], long * isize)
+int asys_getbuf(ASYS_ITYPE * asys_ibuf[], int * isize)
 
 {
   if (*asys_ibuf == NULL)
     *asys_ibuf = asysi_buf;
-  *isize = (long)rread(*asys_ibuf, sizeof(short), asysi_size, asysi_fd);
+  *isize = (int)rread(*asys_ibuf, sizeof(short), asysi_size, asysi_fd);
   asysi_nsamp += *isize;
   return ASYS_DONE;
 }
