@@ -40,9 +40,9 @@
 /******************************************************************/
 /*                                                                */
 /* This file defines two functions ksyncinit(), called before     */
-/* the first ipass begins, and ksync(), called at the start      */
+/* the first ipass begins, and ksync(), called at the start       */
 /* of every ipass. These routines act to ensure that each         */
-/* sequence of IPASS/KPASS/APASS takes at least KUTIME. ksync     */
+/* sequence of IPASS/KPASS/APASS takes at least EV(KUTIME). ksync */
 /* returns an estimate of cpuload, range [0.0:1.0], which codes   */
 /* what fraction of the kcycle was used for computing audio.      */
 /*                                                                */
@@ -54,9 +54,9 @@
 /* (2) Define both ksync() and ksyncinit().                       */
 /*                                                                */
 /* Note that:                                                     */
-/*  KUTIME: a long,  defines k-cycle length in microseconds       */
-/*  KMTIME: a float, defines k-cycle length in milliseconds       */
-/*  KTIME:  a float, defines k-cycle length in seconds            */
+/*  EV(KUTIME): an int, defines k-cycle length in microseconds    */
+/*  EV(KMTIME): a float, defines k-cycle length in milliseconds   */
+/*  EV(KTIME):  a float, defines k-cycle length in seconds        */
 /******************************************************************/
 
 
@@ -64,9 +64,7 @@
 
 #define SYNC_ONESECOND 1000000L
 #define SYNC_SELDELAY 1000L
-#define SYNC_NORM (1.0F/KUTIME)
-
-struct timeval sync_last, sync_this, sync_delay;
+#define SYNC_NORM (1.0F/EV(KUTIME))
 
 /***********************************************************/
 /*         synchronizes on k-rate boundaries               */
@@ -77,49 +75,49 @@ float ksync()
 {
   float ret = 1.0F;
 
-  if ((sync_last.tv_usec += KUTIME) < SYNC_ONESECOND) /* non-rollover case */
+  if ((EV(sync_last.tv_usec) += EV(KUTIME)) < SYNC_ONESECOND) /* non-rollover case */
     {
-      gettimeofday(&sync_this, NULL);
-      if (((sync_delay.tv_usec = sync_last.tv_usec - sync_this.tv_usec) >= 0)
-	  && (sync_last.tv_sec == sync_this.tv_sec))
+      gettimeofday(&EV(sync_this), NULL);
+      if (((EV(sync_delay.tv_usec) = EV(sync_last.tv_usec) - EV(sync_this.tv_usec)) >= 0)
+	  && (EV(sync_last.tv_sec) == EV(sync_this.tv_sec)))
 	{
-	  ret -= SYNC_NORM*sync_delay.tv_usec;
+	  ret -= SYNC_NORM*EV(sync_delay.tv_usec);
 	  ret = (ret > 0.0F) ? ret : 0.0F;
 
-	  if ((sync_delay.tv_usec -= SYNC_SELDELAY) > 0)
-	    select(0, NULL, NULL, NULL, &sync_delay);
+	  if ((EV(sync_delay.tv_usec) -= SYNC_SELDELAY) > 0)
+	    select(0, NULL, NULL, NULL, &EV(sync_delay));
 
 	  do 
-	    gettimeofday(&sync_this, NULL);
-	  while (((sync_this.tv_sec == sync_last.tv_sec))
-		 &&(sync_last.tv_usec > sync_this.tv_usec));
+	    gettimeofday(&EV(sync_this), NULL);
+	  while (((EV(sync_this.tv_sec) == EV(sync_last.tv_sec)))
+		 &&(EV(sync_last.tv_usec) > EV(sync_this.tv_usec)));
 	}
       return ret;
     }
 
-  sync_last.tv_sec++;
-  sync_last.tv_usec %= SYNC_ONESECOND;
+  EV(sync_last.tv_sec)++;
+  EV(sync_last.tv_usec) %= SYNC_ONESECOND;
 
-  gettimeofday(&sync_this, NULL);
-  if ((sync_last.tv_sec > sync_this.tv_sec) ||
-      ((sync_last.tv_sec == sync_this.tv_sec) &&
-       ((sync_delay.tv_usec = sync_last.tv_usec - sync_this.tv_usec) >= 0)))
+  gettimeofday(&EV(sync_this), NULL);
+  if ((EV(sync_last.tv_sec) > EV(sync_this.tv_sec)) ||
+      ((EV(sync_last.tv_sec) == EV(sync_this.tv_sec)) &&
+       ((EV(sync_delay.tv_usec) = EV(sync_last.tv_usec) - EV(sync_this.tv_usec)) >= 0)))
     {
-      if (sync_last.tv_sec > sync_this.tv_sec)
-	sync_delay.tv_usec = SYNC_ONESECOND  - sync_this.tv_usec
-	  + sync_last.tv_usec;
+      if (EV(sync_last.tv_sec) > EV(sync_this.tv_sec))
+	EV(sync_delay.tv_usec) = SYNC_ONESECOND  - EV(sync_this.tv_usec)
+	  + EV(sync_last.tv_usec);
 
-      ret -= SYNC_NORM*sync_delay.tv_usec;
+      ret -= SYNC_NORM*EV(sync_delay.tv_usec);
       ret = (ret > 0.0F) ? ret : 0.0F;
 
-      if ((sync_delay.tv_usec -= SYNC_SELDELAY) > 0)
-	select(0, NULL, NULL, NULL, &sync_delay);
+      if ((EV(sync_delay.tv_usec) -= SYNC_SELDELAY) > 0)
+	select(0, NULL, NULL, NULL, &EV(sync_delay));
 
       do
-	gettimeofday(&sync_this, NULL);
-      while ((sync_last.tv_sec > sync_this.tv_sec) || 
-	     ((sync_last.tv_sec == sync_this.tv_sec) &&
-	      (sync_last.tv_usec > sync_this.tv_usec)));
+	gettimeofday(&EV(sync_this), NULL);
+      while ((EV(sync_last.tv_sec) > EV(sync_this.tv_sec)) || 
+	     ((EV(sync_last.tv_sec) == EV(sync_this.tv_sec)) &&
+	      (EV(sync_last.tv_usec) > EV(sync_this.tv_usec))));
     }
   return ret;
 
@@ -132,8 +130,8 @@ float ksync()
 void ksyncinit()
 
 {
-  sync_delay.tv_sec = 0;
-  gettimeofday(&sync_last, NULL);
+  EV(sync_delay.tv_sec) = 0;
+  gettimeofday(&EV(sync_last), NULL);
 }
 
 
