@@ -86,8 +86,8 @@ unsigned char csysi_hold[CSYSI_BUFFSIZE];
 int csysi_holdidx = 0;
 
 unsigned char csysi_data[CSYSI_BUFFSIZE];
-long csysi_len;
-long csysi_cnt;
+int csysi_len;
+int csysi_cnt;
 unsigned char csysi_cmd;
 unsigned char csysi_num;
 unsigned short csysi_extchan;
