@@ -191,7 +191,7 @@ int csys_midievent(unsigned char * cmd,   unsigned char * ndata,
   if (csysi_exitFlag)
     {
       *cmd = CSYS_MIDI_ENDTIME;
-      *fval = scorebeats;
+      *fval = EV(scorebeats);
       return CSYS_NONE;
     }
 
