@@ -96,14 +96,14 @@ unsigned char nsys_netout_markbit; /* for setting markerbit */
 
 struct nsys_payinfo nsys_payload_types[NSYS_RTP_PAYSIZE] = 
 { 
-  {NSYS_MPEG4_PINDEX,  96, "mpeg4-generic", (int)(ARATE + 0.5F)},
-  {NSYS_NATIVE_PINDEX, 97, "rtp-midi", (int)(ARATE + 0.5F)}
+  {NSYS_MPEG4_PINDEX,  96, "mpeg4-generic", (int)(EV(ARATE) + 0.5F)},
+  {NSYS_NATIVE_PINDEX, 97, "rtp-midi", (int)(EV(ARATE) + 0.5F)}
 };
 #endif
 
 struct nsys_payinfo nsys_payload_types[NSYS_RTP_PAYSIZE] = 
 { 
-  {NSYS_MPEG4_PINDEX, 96, "pre1-mpeg4-generic", (int)(ARATE + 0.5F)}
+  {NSYS_MPEG4_PINDEX, 96, "pre1-mpeg4-generic", (int)(EV(ARATE) + 0.5F)}
 };
 
 /**************/
