@@ -72,7 +72,7 @@ int nsys_netin_journal_recovery(nsys_source * sptr, int rtpcode,
 
 #if (NSYS_LATENOTES_DEBUG == NSYS_LATENOTES_DEBUG_ON)
       if (sptr->tm_margin)
-	printf("Time: %f\n", (nsys_netout_tstamp - sptr->tm_first)/ARATE);
+	printf("Time: %f\n", (nsys_netout_tstamp - sptr->tm_first)/EV(ARATE));
 #endif
 
       fflush(stdout);
