@@ -317,18 +317,18 @@ int nsys_setup(int block)
     break;
   case NSYS_SM_FEC_MINIMAL:
     nsys_netout_jsend_guard_ontime  = 0;
-    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_MINTIME)/ACYCLE;
-    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_mintime = (EV(ARATE)*NSYS_SM_GUARD_MINTIME)/EV(ACYCLE);
+    nsys_netout_jsend_guard_maxtime = (EV(ARATE)*NSYS_SM_GUARD_MAXTIME)/EV(ACYCLE);
     break;
   case NSYS_SM_FEC_STANDARD:
     nsys_netout_jsend_guard_ontime  = 0;
-    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
-    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_mintime = (EV(ARATE)*NSYS_SM_GUARD_STDTIME)/EV(ACYCLE);
+    nsys_netout_jsend_guard_maxtime = (EV(ARATE)*NSYS_SM_GUARD_MAXTIME)/EV(ACYCLE);
     break;
   case NSYS_SM_FEC_EXTRA:
-    nsys_netout_jsend_guard_ontime  = (ARATE*NSYS_SM_GUARD_ONTIME)/ACYCLE;
-    nsys_netout_jsend_guard_mintime = (ARATE*NSYS_SM_GUARD_STDTIME)/ACYCLE;
-    nsys_netout_jsend_guard_maxtime = (ARATE*NSYS_SM_GUARD_MAXTIME)/ACYCLE;
+    nsys_netout_jsend_guard_ontime  = (EV(ARATE)*NSYS_SM_GUARD_ONTIME)/EV(ACYCLE);
+    nsys_netout_jsend_guard_mintime = (EV(ARATE)*NSYS_SM_GUARD_STDTIME)/EV(ACYCLE);
+    nsys_netout_jsend_guard_maxtime = (EV(ARATE)*NSYS_SM_GUARD_MAXTIME)/EV(ACYCLE);
     break;
   }
 
@@ -578,8 +578,8 @@ int nsys_netin_rtpstats(nsys_source * sptr, unsigned char * packet)
   if (sptr->tm_margin)
     {
       fprintf(sptr->tm_fd, "%f %f #",
-	      (nsys_netout_tstamp - sptr->tm_first)/ARATE,
-	      ((int)(delta + sptr->tm_convert))/ARATE);
+	      (nsys_netout_tstamp - sptr->tm_first)/EV(ARATE),
+	      ((int)(delta + sptr->tm_convert))/EV(ARATE));
 
       /* not checking length, but not dangerous */
 
