@@ -69,7 +69,7 @@ int nsys_newdata(void)
 
   nsys_bufflen = nsys_buffcnt = 0;
 
-  nsys_netout_tstamp += ACYCLE;
+  nsys_netout_tstamp += EV(ACYCLE);
 
   if (nsys_netout_jsend_guard_time && ((--nsys_netout_jsend_guard_time) == 0))
     nsys_netout_guard_tick();
@@ -895,8 +895,8 @@ void nsys_endcycle(void)
  if (nsys_netout_jsend_guard_send) 
    nsys_midisend(CSYS_MIDI_NOOP, 0, 0, 0);
  
- if (nsys_graceful_exit && !graceful_exit)
-   graceful_exit = 1;
+ if (nsys_graceful_exit && !EV(graceful_exit))
+   EV(graceful_exit) = 1;
 
 }
 
