@@ -62,10 +62,10 @@ void readnextbyte(void)
 /******************************************************************/
 
 
-unsigned long readbit(unsigned long numbits)
+unsigned int readbit(unsigned int numbits)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
 
   while (numbits > 0)
     {
@@ -87,7 +87,7 @@ int readaccesstime()
 
 {
   int numbits = 32;
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
 
 
   u.l = 0;
@@ -120,7 +120,7 @@ int readaccesstime()
 /******************************************************************/
 
 
-void readflush(unsigned long numbits)
+void readflush(unsigned int numbits)
 
 {
 
@@ -269,7 +269,7 @@ void scorelineflush(void)
 void scorefileflush(void)
 
 {
-  unsigned long numlines;
+  unsigned int numlines;
 
   numlines = readbit(20);
   while (numlines > 0)
@@ -288,7 +288,7 @@ void sampleflush(void)
 
 {
 
-  unsigned long len;
+  unsigned int len;
 
   readflush(16);       /* symbol */
   len = readbit(24);   
@@ -363,10 +363,10 @@ void putsoundbytes(unsigned char * c, int numbytes)
 }
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-void wavefileintwrite(unsigned long val, int numbytes)
+void wavefileintwrite(unsigned int val, int numbytes)
 
 {
   unsigned char c[4];
@@ -413,8 +413,8 @@ void wavefileintwrite(unsigned long val, int numbytes)
 void readnextsample(void)
 
 {
-  union { unsigned long l; float f ; } u;
-  unsigned long len;
+  union { unsigned int l; float f ; } u;
+  unsigned int len;
   int srate = 0;         /* initialization not needed */
   char name[STRSIZE];
   int hasbase, hasloop, unity, fract;
@@ -424,7 +424,7 @@ void readnextsample(void)
   float base = 0.0F;
 
 
-  sprintf(name,"a%li",readbit(16));
+  sprintf(name,"a%i",readbit(16));
   addvsym(&bitsamplein, dupval(name), K_INTERNAL);
   len = readbit(24);   
   if (readbit(1))      /* srate */
@@ -468,7 +468,7 @@ void readnextsample(void)
       while (len > 0)
 	{
 	  u.l = readbit(32);
-	  wavefileintwrite((long)(u.f*(pow(2,23) - 1)), 3); 
+	  wavefileintwrite((int)(u.f*(pow(2,23) - 1)), 3); 
 	  len--;
 	}
     }
@@ -628,9 +628,9 @@ int readprepare(int goal)
 int orclex(void)
 
 {
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   int ret, token, symbol, len, i;
-  unsigned long intgr;
+  unsigned int intgr;
   char name[32];
 
 
@@ -676,7 +676,7 @@ int orclex(void)
     return NUMBER;
   case S_INTGR:
     intgr = readbit(32);
-    sprintf(name,"%lu",intgr);
+    sprintf(name,"%u",intgr);
     yylval = make_tnode(dupval(name), token);
     yylval->rate =  IRATETYPE;
     yylval->res = ASINT;
@@ -684,7 +684,7 @@ int orclex(void)
     return INTGR;
   case S_BYTE:
     intgr = readbit(8);
-    sprintf(name,"%li",intgr);
+    sprintf(name,"%i",intgr);
     yylval = make_tnode(dupval(name), S_INTGR);
     yylval->rate =  IRATETYPE;
     yylval->res = ASINT;
@@ -768,7 +768,7 @@ int orclex(void)
 void binscorelinetop(void)
 
 {
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   int haslabel;
 
 
@@ -868,7 +868,7 @@ tnode * binscoretimestamp(int type)
 tnode * binscorelinebottom(int type)
 
 {
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   char name[64];
  
 
@@ -902,7 +902,7 @@ tnode * binscorelinebottom(int type)
 	case 3:
 	  return make_tnode(dupval("control"), S_CONTROL);
 	case 2:
-	  sprintf(name,"a%li",readbit(16)); 
+	  sprintf(name,"a%i",readbit(16)); 
 	  return make_tnode(dupval(name), S_IDENT);
 	case 1:
 	  u.l = readbit(32);
@@ -921,7 +921,7 @@ tnode * binscorelinebottom(int type)
 	case 3:
 	  return make_tnode(dupval("control"), S_CONTROL);
 	case 2:
-	  sprintf(name,"a%li",readbit(16)); 
+	  sprintf(name,"a%i",readbit(16)); 
 	  return make_tnode(dupval(name), S_IDENT);
 	case 1:
 	  u.l = readbit(32);
@@ -964,7 +964,7 @@ tnode * binscorelinebottom(int type)
 	case 3:
 	  return binscoretimestamp(type);
 	case 2:
-	  sprintf(name,"a%li",readbit(16)); 
+	  sprintf(name,"a%i",readbit(16)); 
 	  return make_tnode(dupval(name), S_IDENT);
 	}
       }
@@ -979,7 +979,7 @@ tnode * binscorelinebottom(int type)
 	case 3:
 	  return binscoretimestamp(type);
 	case 2:
-	  sprintf(name,"a%li",readbit(16)); 
+	  sprintf(name,"a%i",readbit(16)); 
 	  return make_tnode(dupval(name), S_IDENT);
 	}
       }
@@ -1019,7 +1019,7 @@ tnode * binscorelinebottom(int type)
 		(bitscopfieldsmax != bitscopfields))
 	      {
 		u.l = readbit(16);      /* table token */
-		sprintf(name,"a%li", u.l);
+		sprintf(name,"a%i", u.l);
 		bitscopfields--;
 		if (!bitscopfields)
 		  {
@@ -1066,7 +1066,7 @@ tnode * binscorelinebottom(int type)
     case 3:
       return make_tnode(dupval("table"), S_TABLE);
     case 2:
-      sprintf(name,"a%li",readbit(16)); 
+      sprintf(name,"a%i",readbit(16)); 
       return make_tnode(dupval(name), S_IDENT);
     }
     break;
