@@ -45,7 +45,7 @@
 /******************************************************************/
 
 
-void bitwrite(unsigned long bitval, unsigned long numbits)
+void bitwrite(unsigned int bitval, unsigned int numbits)
 
 {
 
@@ -194,9 +194,9 @@ void printstateupdate(int * printflag)
 void bitsaolwrite(void)
 
 {
-  unsigned long intval;
+  unsigned int intval;
   int i;
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   sigsym * sptr;
   tnode * saolroot, * tptr, * gptr;
   int ntokens = 2;         /* includes S_EOO */
@@ -321,7 +321,7 @@ void bitsaolwrite(void)
 void bitsymbolwrite(void)
 
 {
-  unsigned long totsym;
+  unsigned int totsym;
   sigsym * sptr;
   int i,j, slen;
 
@@ -365,7 +365,7 @@ void bitsymbolwrite(void)
 void saslpreamble(float reltime, int priority)
 
 {
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   int absolute = 0;
 
   if (absolute)
@@ -390,7 +390,7 @@ void saslpreamble(float reltime, int priority)
 void saslendwrite(char * endstr)
 
 {  
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
 
   if (endstr == NULL)
     return;
@@ -413,7 +413,7 @@ void saslendwrite(char * endstr)
 void sasltempowrite(tnode * tempo)
 
 {  
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
 
   saslpreamble(tempo->time, tempo->special);
   bitwrite(BINTEMPO,3);   /* tempo opcode */
@@ -431,7 +431,7 @@ void sasltempowrite(tnode * tempo)
 void sasltablewrite(tnode * table, int sampletoken)
 
 {  
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   sigsym * sptr;
   int j, token;
   tnode * tptr;
@@ -503,7 +503,7 @@ void sasltablewrite(tnode * table, int sampletoken)
 void saslinstrwrite(tnode * instr)
 
 {  
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   sigsym * sptr;
   int j;
   tnode * tptr;
@@ -561,7 +561,7 @@ void saslinstrwrite(tnode * instr)
 void saslcontrolwrite(tnode * control)
 
 {  
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
   sigsym * sptr;
   tnode * tptr;
 
@@ -606,7 +606,7 @@ void saslcontrolwrite(tnode * control)
 void bitscorewrite(void)
 
 {
-  unsigned long totscore;
+  unsigned int totscore;
   int i;
   tnode * tempo, * table, * control, * instr;
   sigsym * sptr;
@@ -702,7 +702,7 @@ void bitmidiwrite(void)
 
 {
   unsigned char c;
-  unsigned long i = confmidi->midifsize;
+  unsigned int i = confmidi->midifsize;
 
   bitwrite(1,1);        /* more data */
   bitwrite(BINMIDI,3);  /* a midi file */
@@ -802,13 +802,13 @@ void flushsoundbytes(int numbytes)
 }
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-unsigned long wavefileintval(int numbytes)
+unsigned int wavefileintval(int numbytes)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[4];
 
   if (numbytes > 4)
@@ -819,22 +819,22 @@ unsigned long wavefileintval(int numbytes)
   getsoundbytes(&c[0],numbytes);
   switch (numbytes) {
   case 4:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[2] << 16;
-    ret |=  (unsigned long)c[3] << 24;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[2] << 16;
+    ret |=  (unsigned int)c[3] << 24;
     break;
   case 3:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[2] << 16;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[2] << 16;
     break;
   case 2:
-    ret  =  (unsigned long)c[0];
-    ret |=  (unsigned long)c[1] << 8;
+    ret  =  (unsigned int)c[0];
+    ret |=  (unsigned int)c[1] << 8;
     break;
   case 1:
-    ret = ((unsigned long)c[0]);
+    ret = ((unsigned int)c[0]);
     break;
   default:
     break;
@@ -845,13 +845,13 @@ unsigned long wavefileintval(int numbytes)
 
   
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-unsigned long aiffileintval(int numbytes)
+unsigned int aiffileintval(int numbytes)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[4];
 
   if (numbytes > 4)
@@ -862,22 +862,22 @@ unsigned long aiffileintval(int numbytes)
   getsoundbytes(&c[0],numbytes);
   switch (numbytes) {
   case 4:
-    ret  =  (unsigned long)c[3];
-    ret |=  (unsigned long)c[2] << 8;
-    ret |=  (unsigned long)c[1] << 16;
-    ret |=  (unsigned long)c[0] << 24;
+    ret  =  (unsigned int)c[3];
+    ret |=  (unsigned int)c[2] << 8;
+    ret |=  (unsigned int)c[1] << 16;
+    ret |=  (unsigned int)c[0] << 24;
     break;
   case 3:
-    ret  =  (unsigned long)c[2];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[0] << 16;
+    ret  =  (unsigned int)c[2];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[0] << 16;
     break;
   case 2:
-    ret  =  (unsigned long)c[1];
-    ret |=  (unsigned long)c[0] << 8;
+    ret  =  (unsigned int)c[1];
+    ret |=  (unsigned int)c[0] << 8;
     break;
   case 1:
-    ret = ((unsigned long)c[0]);
+    ret = ((unsigned int)c[0]);
     break;
   default:
     break;
@@ -915,13 +915,13 @@ int soundtypecheck(char * d)
 void nextsamplewrite(sigsym * sptr)
 
 {
-  unsigned long len = 0;
-  unsigned long i, j, m, e;
-  unsigned long srate = 0;  
-  long channels = 1;         /* number of channels for the file              */
-  long numbytes = 2;         /* number of bytes in a data word               */    
-  long framebytes = 2;       /* number of bytes in one N-channel frame       */
-  long chanpoint = 0;        /* 1st byte of channel in frame; -1 sum to mono */
+  unsigned int len = 0;
+  unsigned int i, j, m, e;
+  unsigned int srate = 0;  
+  int channels = 1;         /* number of channels for the file              */
+  int numbytes = 2;         /* number of bytes in a data word               */    
+  int framebytes = 2;       /* number of bytes in one N-channel frame       */
+  int chanpoint = 0;        /* 1st byte of channel in frame; -1 sum to mono */
   sigsym * s2ptr;
   unsigned char cookie[4];
   char name[STRSIZE];
@@ -929,17 +929,17 @@ void nextsamplewrite(sigsym * sptr)
   char at_n = -1;
   int ntotal = 0;
   int extlen, padbyte, markers;
-  long * sbuff = NULL;
-  long unity = 0;
-  long fract = 0;
-  long start = 0;
-  long end = 0;
-  long hasbase = 0;
-  long hasloop = 0;
+  int * sbuff = NULL;
+  int unity = 0;
+  int fract = 0;
+  int start = 0;
+  int end = 0;
+  int hasbase = 0;
+  int hasloop = 0;
   char c;
   struct aiffmark * mptr = NULL;
   struct aiffmark * mhead = NULL;
-  union { unsigned long l; float f ; } fwr;
+  union { unsigned int l; float f ; } fwr;
 
 
   sprintf(name,"_sym_sample%i",sptr->special);
@@ -1017,7 +1017,7 @@ void nextsamplewrite(sigsym * sptr)
 	      if (at_n > channels - 1)
 		{
 		  printf("Error: Sample generator @%i filename syntax requests\n"
-			 "       the %i'th channel of an %li channel samplefile %s.\n", 
+			 "       the %i'th channel of an %i channel samplefile %s.\n", 
 			 at_n, at_n+1, channels, sptr->val);
 		  bitsounderror(sptr);
 		}
@@ -1035,7 +1035,7 @@ void nextsamplewrite(sigsym * sptr)
 	    {
 	      padbyte = ((i = wavefileintval(4)) % 2);
 	      len = i = i/framebytes;
-	      vmcheck(sbuff = (long *) calloc(len, sizeof(long)));
+	      vmcheck(sbuff = (int *) calloc(len, sizeof(int)));
 	      while (i > 0)
 		{
 		  sbuff[len - i] = 0;
@@ -1044,16 +1044,16 @@ void nextsamplewrite(sigsym * sptr)
 		      {
 			switch (numbytes) {
 			case 1:
-			  sbuff[len - i] += (((long)wavefileintval(1))-128)<<8;
+			  sbuff[len - i] += (((int)wavefileintval(1))-128)<<8;
 			  break;
 			case 2:
-			  sbuff[len - i] += ((long)wavefileintval(1));
-			  sbuff[len - i] += ((long)((char)wavefileintval(1))) << 8;
+			  sbuff[len - i] += ((int)wavefileintval(1));
+			  sbuff[len - i] += ((int)((char)wavefileintval(1))) << 8;
 			  break;
 			case 3:
-			  sbuff[len - i] += ((long)wavefileintval(1));
-			  sbuff[len - i] += (((long)wavefileintval(1)) << 8);
-			  sbuff[len - i] += ((long)((char)wavefileintval(1))) << 16;
+			  sbuff[len - i] += ((int)wavefileintval(1));
+			  sbuff[len - i] += (((int)wavefileintval(1)) << 8);
+			  sbuff[len - i] += ((int)((char)wavefileintval(1))) << 16;
 			  break;
 			}
 		      }
@@ -1157,7 +1157,7 @@ void nextsamplewrite(sigsym * sptr)
 	    framebytes = channels*numbytes;
 	    e = ((short)aiffileintval(2))&0x7FFF;
 	    m = aiffileintval(4);
-	    srate = (unsigned long) (0.5 + (m*exp(log(2)*(e - 16414.0F))));
+	    srate = (unsigned int) (0.5 + (m*exp(log(2)*(e - 16414.0F))));
 	    if (channels == 1)
 	      chanpoint = 0;
 	    else
@@ -1167,7 +1167,7 @@ void nextsamplewrite(sigsym * sptr)
 		    if (at_n > channels - 1)
 		      {
 			printf("Error: Sample generator @%i filename syntax requests\n"
-			       "       the %i'th channel of an %li channel samplefile %s.\n", 
+			       "       the %i'th channel of an %i channel samplefile %s.\n", 
 			       at_n, at_n+1, channels, sptr->val);
 			bitsounderror(sptr);
 		      }
@@ -1196,7 +1196,7 @@ void nextsamplewrite(sigsym * sptr)
 	      padbyte = ((i = (aiffileintval(4) - 8)) % 2);
 	      len = i = i/framebytes;
 	      flushsoundbytes(8);
-	      vmcheck(sbuff = (long *) calloc(len, sizeof(long)));
+	      vmcheck(sbuff = (int *) calloc(len, sizeof(int)));
 	      while (i > 0)
 		{
 		  sbuff[len - i] = 0;
@@ -1205,16 +1205,16 @@ void nextsamplewrite(sigsym * sptr)
 		      {
 			switch (numbytes) {
 			case 1:
-			  sbuff[len - i] += ((long)((char)wavefileintval(1))) << 8;
+			  sbuff[len - i] += ((int)((char)wavefileintval(1))) << 8;
 			  break;
 			case 2:
-			  sbuff[len - i] += ((long)((char)wavefileintval(1))) << 8;
-			  sbuff[len - i] += ((long)wavefileintval(1));
+			  sbuff[len - i] += ((int)((char)wavefileintval(1))) << 8;
+			  sbuff[len - i] += ((int)wavefileintval(1));
 			  break;
 			case 3:
-			  sbuff[len - i] += ((long)((char)wavefileintval(1))) << 16;
-			  sbuff[len - i] += (((long)wavefileintval(1)) << 8);
-			  sbuff[len - i] += ((long)wavefileintval(1));
+			  sbuff[len - i] += ((int)((char)wavefileintval(1))) << 16;
+			  sbuff[len - i] += (((int)wavefileintval(1)) << 8);
+			  sbuff[len - i] += ((int)wavefileintval(1));
 			  break;
 			}
 		      }
@@ -1297,7 +1297,7 @@ void nextsamplewrite(sigsym * sptr)
 		{
 		  j = 1;
 		  start = mptr->position;
-		  if ((unsigned long)start == len)
+		  if ((unsigned int)start == len)
 		    start--;
 		  break;
 		}
@@ -1313,7 +1313,7 @@ void nextsamplewrite(sigsym * sptr)
 		{
 		  j = 1;
 		  end = mptr->position;
-		  if ((unsigned long)end == len)
+		  if ((unsigned int)end == len)
 		    end--;
 		  break;
 		}
@@ -1663,7 +1663,7 @@ void startaccessunit(float timestamp)
 
 {
 
-  union { unsigned long l; float f ; } u;
+  union { unsigned int l; float f ; } u;
 
   u.f = timestamp;
   bitwrite(u.l, 32);
@@ -1711,7 +1711,7 @@ void bitstreamingmidiinit(void)
   if (sstrmidi->midinumchan > 15)
     {
       printf("Error: MIDI streaming write only handles 16 MIDI channels.\n");
-      printf("       The -mstr file has %li channels and can't be streamed.\n",
+      printf("       The -mstr file has %i channels and can't be streamed.\n",
 	     sstrmidi->midinumchan);
       printf("       To do a non-streaming encode, use the -midi option.\n");
       noerrorplace();
