@@ -483,7 +483,7 @@ void ratefactor(tnode * tptr, tnode ** lines,  int *num,  int newres)
   if (addsym(&locsymtable, nptr) != INSTALLED)
     internalerror("optrate.c","error 1 in ratefactor()");
   nptr->sptr = locsymtable;
-  vmcheck(nptr->sptr->tref = (trefer *) calloc(1L, sizeof(trefer)));
+  vmcheck(nptr->sptr->tref = (trefer *) calloc(1, sizeof(trefer)));
   nptr->vartype = nptr->sptr->vartype = tptr->vartype;
   nptr->vol = nptr->sptr->vol =  tptr->vol;
 
@@ -920,7 +920,7 @@ void tmapfactor(tnode * tptr, tnode ** lines,  int *num)
   nptr->vartype = nptr->sptr->vartype = TABLETYPE;
   nptr->sptr->kind = K_INTERNAL;
   nptr->vol = nptr->sptr->vol = VARIABLE;
-  vmcheck(nptr->sptr->tref =  (trefer *) calloc(1L, sizeof(trefer)));
+  vmcheck(nptr->sptr->tref =  (trefer *) calloc(1, sizeof(trefer)));
 
   /* expression is tablemap indexing expression */
 
