@@ -188,13 +188,13 @@ int miditypecheck(midata * mdata, int type, char * d)
   
 
 /*********************************************************/
-/*     converts byte stream to an unsigned long          */
+/*     converts byte stream to an unsigned int          */
 /*********************************************************/
 
-unsigned long intval(midata * mdata, int type, int numbytes)
+unsigned int intval(midata * mdata, int type, int numbytes)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[4];
 
   if (numbytes > 4)
@@ -202,22 +202,22 @@ unsigned long intval(midata * mdata, int type, int numbytes)
   getmidibytes(mdata, type, &c[0],numbytes);
   switch (numbytes) {
   case 4:
-    ret  =  (unsigned long)c[3];
-    ret |=  (unsigned long)c[2] << 8;
-    ret |=  (unsigned long)c[1] << 16;
-    ret |=  (unsigned long)c[0] << 24;
+    ret  =  (unsigned int)c[3];
+    ret |=  (unsigned int)c[2] << 8;
+    ret |=  (unsigned int)c[1] << 16;
+    ret |=  (unsigned int)c[0] << 24;
     break;
   case 3:
-    ret  =  (unsigned long)c[2];
-    ret |=  (unsigned long)c[1] << 8;
-    ret |=  (unsigned long)c[0] << 16;
+    ret  =  (unsigned int)c[2];
+    ret |=  (unsigned int)c[1] << 8;
+    ret |=  (unsigned int)c[0] << 16;
     break;
   case 2:
-    ret  =  (unsigned long)c[1];
-    ret |=  (unsigned long)c[0] << 8;
+    ret  =  (unsigned int)c[1];
+    ret |=  (unsigned int)c[0] << 8;
     break;
   case 1:
-    ret = ((unsigned long)c[0]);
+    ret = ((unsigned int)c[0]);
     break;
   default:
     break;
@@ -229,10 +229,10 @@ unsigned long intval(midata * mdata, int type, int numbytes)
 /*     extracts tick-per-quarter-note from stream        */
 /*********************************************************/
 
-unsigned long tickval(midata * mdata, int type)
+unsigned int tickval(midata * mdata, int type)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c[2];
 
   getmidibytes(mdata, type, &c[0],2);
@@ -243,8 +243,8 @@ unsigned long tickval(midata * mdata, int type)
     }
   else
     {
-      ret  =  (unsigned long)c[1];
-      ret |=  (unsigned long)c[0] << 8;
+      ret  =  (unsigned int)c[1];
+      ret |=  (unsigned int)c[0] << 8;
     }
   return ret;
 
@@ -254,7 +254,7 @@ unsigned long tickval(midata * mdata, int type)
 /*     flushes unneeded bytes from MIDI stream           */
 /*********************************************************/
 
-void flushmidi(midata * mdata, int type, unsigned long len)
+void flushmidi(midata * mdata, int type, unsigned int len)
 
 {
   unsigned char c;
@@ -273,7 +273,7 @@ void flushmidi(midata * mdata, int type, unsigned long len)
 /*********************************************************/
 
 void textoutmidi(midata * mdata, int type, 
-		 unsigned long len, char * prepend)
+		 unsigned int len, char * prepend)
 
 {
   unsigned char c;
@@ -300,18 +300,18 @@ void textoutmidi(midata * mdata, int type,
 /*        reads variable-length number MIDI number       */
 /*********************************************************/
 
-unsigned long getvlength(midata * mdata, int type, 
-			 unsigned long * len)
+unsigned int getvlength(midata * mdata, int type, 
+			 unsigned int * len)
 
 {
-  unsigned long ret = 0;
+  unsigned int ret = 0;
   unsigned char c;
 
   do {
     getmidibytes(mdata, type, &c, 1);
     (*len)--;
     ret = ret << 7;
-    ret |= ((unsigned long)(c&0x7F));
+    ret |= ((unsigned int)(c&0x7F));
     } 
   while (c&0x80);
   return ret;
@@ -324,7 +324,7 @@ unsigned long getvlength(midata * mdata, int type,
 
 void nextmidicommand(midata * mdata,
 		     int type, 
-		     unsigned long * len, 
+		     unsigned int * len, 
 		     unsigned char * command,
 		     unsigned char * d0)
 
@@ -396,12 +396,12 @@ tnode * miditimestampptr(midata * mdata)
 void midisyscommands(midata * mdata,
 		     int type,
 		     sasdata * sdata,
-		     unsigned long * len,
+		     unsigned int * len,
 		     unsigned char command)
 
 
 {
-  unsigned long flen,i;
+  unsigned int flen,i;
   char tname[STRSIZE];
   tnode * tptr;
   
@@ -440,7 +440,7 @@ void midisyscommands(midata * mdata,
   switch (command) {
   case METASEQNUM:
     if (midiverbose)
-      printf("Sequence Number %li\n", intval(mdata, type, 2));
+      printf("Sequence Number %i\n", intval(mdata, type, 2));
     else
       flushmidi(mdata, type, flen);
     break;
@@ -469,14 +469,14 @@ void midisyscommands(midata * mdata,
     if (midiverbose)
       {
 	i = intval(mdata, type, 1);
-	printf("On Ext Channel %li (%li):\n",16*mdata->miditracks+i,i);
+	printf("On Ext Channel %i (%i):\n",16*mdata->miditracks+i,i);
       }
     else
       flushmidi(mdata, type, flen);
     break; 
   case METAPORT:
     if (midiverbose)
-      printf("On Port %li:\n",intval(mdata, type, 1));
+      printf("On Port %i:\n",intval(mdata, type, 1));
     else
       flushmidi(mdata, type, flen);
     break;    
@@ -491,7 +491,7 @@ void midisyscommands(midata * mdata,
     break;
   case METASMPTE:
     if (midiverbose)
-      printf("SMPTE Offset %li %li %li %li %li\n",
+      printf("SMPTE Offset %i %i %i %i %i\n",
 	     intval(mdata, type, 1), intval(mdata, type, 1), intval(mdata, type, 1),
 	     intval(mdata, type, 1), intval(mdata, type, 1));
     else
@@ -499,7 +499,7 @@ void midisyscommands(midata * mdata,
     break;   
   case METATIMESIG:
     if (midiverbose)
-      printf("Time Signature: %li/%li, (MIDI %li %li), \n",
+      printf("Time Signature: %i/%i, (MIDI %i %i), \n",
 	     intval(mdata, type, 1), intval(mdata, type, 1),
 	     intval(mdata, type, 1), intval(mdata, type, 1));
     else
@@ -524,7 +524,7 @@ void midisummary(midata * mdata)
   int i;
 
   printf("Summary of MIDI File\n");
-  printf("Beat Length %f, Number of Minimal Extended Channels %li\n",
+  printf("Beat Length %f, Number of Minimal Extended Channels %i\n",
 	 (float)mdata->midimaxtime/mdata->miditicks, mdata->midinumchan);
   tptr = mdata->imidiroot;
   while (tptr != NULL)
@@ -595,7 +595,7 @@ void newpatch(midata * mdata, unsigned int chan, unsigned int patch)
   sptr = getvsym(&instrpresets, pname);
   if (midiverbose)
     {
-      printf("Patch change on channel %li(%i), to preset %i (%i,%i) -- ",
+      printf("Patch change on channel %i(%i), to preset %i (%i,%i) -- ",
 	     mdata->miditracks*16 + chan, chan, midibank[chan]+patch,
 	     midibank[chan],patch);
       if (sptr == NULL)
@@ -655,7 +655,7 @@ void addnote(midata * mdata, unsigned int chan,
 	  sptr = getvsym(&instrpresets, pname);
 	  if (midiverbose)
 	    {
-	      printf("First note on channel %li(%i), try preset %i (%i,0) -- ",
+	      printf("First note on channel %i(%i), try preset %i (%i,0) -- ",
 		     mdata->miditracks*16 + chan, chan, midibank[chan],
 		     midibank[chan]);
 	      if (sptr == NULL)
@@ -776,20 +776,20 @@ void midicleanup(midata * mdata)
     for (i = 0; i < MCHAN; i++)
       {
 	if (midihastouchc[i])
-	  printf("Ext chan %li(%i) has %i chan-touch events\n",
+	  printf("Ext chan %i(%i) has %i chan-touch events\n",
 		 mdata->miditracks*MCHAN+i,i,midihastouchc[i]);
 	if (midihastouchk[i])
-	  printf("Ext chan %li(%i) has %i key-touch events\n",
+	  printf("Ext chan %i(%i) has %i key-touch events\n",
 		 mdata->miditracks*MCHAN+i,i,midihastouchk[i]);
 	if (midihaswheel[i])
-	  printf("Ext chan %li(%i) has %i wheel events\n",
+	  printf("Ext chan %i(%i) has %i wheel events\n",
 		 mdata->miditracks*MCHAN+i,i,midihaswheel[i]);
 	k = 0;
 	for (j = 0; j < MNOTE; j++)
 	  k |= midihasctrlflag[i][j];
 	if (k > 0)
 	  {
-	    printf("Ext chan %li(%i) uses controllers:", 
+	    printf("Ext chan %i(%i) uses controllers:", 
 		   mdata->miditracks*MCHAN + i, i);
 	    for (j = 0; j < MNOTE; j++)
 	      if (midihasctrlflag[i][j] > 0)
@@ -938,7 +938,7 @@ void readmidi(midata * mdata, sasdata * sdata, int type)
 
 {
 
-  unsigned long len;       /* bytes remaining in chunk */
+  unsigned int len;       /* bytes remaining in chunk */
   unsigned char command;   /* current MIDI command */  
   unsigned char d0, d1;    /* data bytes of MIDI command */
   int cookie;
@@ -955,7 +955,7 @@ void readmidi(midata * mdata, sasdata * sdata, int type)
   while ( (cookie = miditypecheck(mdata, type, "MTrk")) != 2)
     {
       if (midiverbose)
-	printf("Track Chunk %li\n",mdata->miditracks);
+	printf("Track Chunk %i\n",mdata->miditracks);
       len = intval(mdata, type, 4);
       if (cookie == 1)
 	{
@@ -1026,16 +1026,114 @@ void readmidi(midata * mdata, sasdata * sdata, int type)
 }
 
 /*********************************************************/
-/*             init -midi: called in writepre.c          */
+/* declares MIDI instr variables (called in writepre.c)  */
 /*********************************************************/
 
-
 void initmidiinstr(int type, sigsym * sptr, int * totlines)
 
 {
   char * prefix;
   char * val;
   tnode * tptr;
+  int i;
+
+  if (type == RELTSTAMP)
+    {
+      tptr = confmidi->imidiroot;
+      prefix = "m";
+      i = sptr->midi;
+    }
+  else
+    {
+      tptr = sstrmidi->imidiroot;
+      prefix = "ma";
+      i = sptr->amidi;
+    }
+
+  while ((tptr != NULL) && ( i > 0))
+    {
+      if (tptr->sptr != sptr)
+	{
+	  tptr = tptr->next;
+	  continue;
+	}
+
+      fprintf(outfile,"instr_line %s%i_%s[%i];\n", prefix,
+	      tptr->special, sptr->val, tptr->arrayidx);
+      (*totlines) +=  tptr->arrayidx;
+      
+      val = dupunderscore(sptr->val);
+      fprintf(outfile,
+	      "instr_line * %s%i_%sfirst;\n", prefix,tptr->special,val);
+      fprintf(outfile,"instr_line * %s%i_%slast;\n",prefix, tptr->special,val);
+      fprintf(outfile,"instr_line * %s%i_%send;\n\n",prefix,tptr->special,val);
+      free(val);
+      i--;
+      tptr = tptr->next;
+    }
+}
+
+
+/*********************************************************/
+/*   content_init() assignments for MIDI instr variables */
+/*********************************************************/
+
+void initmidiinstrassign(int type, sigsym * sptr)
+
+{
+  char * prefix;
+  char * val;
+  tnode * tptr;
+  int i;
+
+  if (type == RELTSTAMP)
+    {
+      tptr = confmidi->imidiroot;
+      prefix = "m";
+      i = sptr->midi;
+    }
+  else
+    {
+      tptr = sstrmidi->imidiroot;
+      prefix = "ma";
+      i = sptr->amidi;
+    }
+
+  while ((tptr != NULL) && ( i > 0) )
+    {
+      if (tptr->sptr != sptr)
+	{
+	  tptr = tptr->next;
+	  continue;
+	}
+
+      fprintf(outfile,"  memcpy(EV(%s%i_%s), %s%i_%s_init, sizeof EV(%s%i_%s));\n", 
+	      prefix, tptr->special, sptr->val, prefix, tptr->special, sptr->val,
+	      prefix, tptr->special, sptr->val);
+
+      val = dupunderscore(sptr->val);
+      fprintf(outfile, "  EV(%s%i_%sfirst) = &EV(%s%i_%s[0]);\n", prefix,
+	      tptr->special,val,prefix,tptr->special,sptr->val);
+      fprintf(outfile,"  EV(%s%i_%slast) = &EV(%s%i_%s[0]);\n",
+	      prefix, tptr->special,val, prefix, tptr->special,sptr->val);
+      fprintf(outfile, "  EV(%s%i_%send) = &EV(%s%i_%s[%i]);\n\n", prefix,
+	      tptr->special,val,prefix,tptr->special,sptr->val,
+	      tptr->arrayidx - 1);
+      free(val);
+      i--;
+      tptr = tptr->next;
+    }
+}
+
+/*********************************************************/
+/* declare and init true constant vars for MIDI instrs  */
+/*********************************************************/
+
+void initmidiinstrconstant(int type, sigsym * sptr)
+
+{
+  char * prefix;
+  tnode * tptr;
   tnode * nptr;
   int i, j, incr;
 
@@ -1062,9 +1160,8 @@ void initmidiinstr(int type, sigsym * sptr, int * totlines)
 	  continue;
 	}
 
-      fprintf(outfile,"struct instr_line %s%i_%s[%i] = {\n", prefix,
+      fprintf(outfile,"instr_line %s%i_%s_init[%i] = {\n", prefix,
 	      tptr->special, sptr->val, tptr->arrayidx);
-      (*totlines) +=  tptr->arrayidx;
       nptr = tptr->down;
       while (nptr != NULL)
 	{
@@ -1136,18 +1233,6 @@ void initmidiinstr(int type, sigsym * sptr, int * totlines)
 	  nptr = nptr->next;
 	}
       fprintf(outfile,"};\n\n");
-      val = dupunderscore(sptr->val);
-      fprintf(outfile,
-	      "struct instr_line * %s%i_%sfirst = &%s%i_%s[0];\n", prefix,
-	      tptr->special,val,prefix,tptr->special,sptr->val);
-      fprintf(outfile,"struct instr_line * %s%i_%slast = &%s%i_%s[0];\n",
-	      prefix, tptr->special,val, prefix, 
-	      tptr->special,sptr->val);
-      fprintf(outfile,
-	      "struct instr_line * %s%i_%send = &%s%i_%s[%i];\n\n", prefix,
-	      tptr->special,val,prefix,tptr->special,sptr->val,
-	      tptr->arrayidx - 1);
-      free(val);
       i--;
       tptr = tptr->next;
     }
@@ -1196,7 +1281,7 @@ void binmidiwrite(int type)
 /*        reads start of the next midi_event             */
 /*********************************************************/
 
-void nextmidievent(unsigned long * len, 
+void nextmidievent(unsigned int * len, 
 		   unsigned char * command,
 		   unsigned char * d0)
 
@@ -1233,12 +1318,12 @@ void nextmidievent(unsigned long * len,
 void midieventread(void)
 
 {
-  unsigned long len;       /* bytes remaining in midi_event */
+  unsigned int len;       /* bytes remaining in midi_event */
   unsigned char command;   /* current MIDI command */  
   unsigned char d0, d1;    /* data bytes of MIDI command */
 
   d0 = d1 = command = 0;
-  len = (unsigned long) readbit(24);
+  len = (unsigned int) readbit(24);
   while (len > 0)
     {
       nextmidievent(&len, &command, &d0);
