@@ -94,30 +94,63 @@ extern void makebufferinit(void);
 void makeloops(char c)
 
 {
-
-  sigsym * sptr = instrnametable;
+  int found = 0;
+  sigsym * sptr;
 
   switch (c) {
   case 'a':
-    fprintf(outfile,"void main_apass(void)\n");
+    fprintf(outfile,"void main_apass(ENGINE_PTR_DECLARE)\n");
     break;
   case 'k':
-    fprintf(outfile,"int main_kpass(void)\n");
+    fprintf(outfile,"int main_kpass(ENGINE_PTR_DECLARE)\n");
     break;
   case 'i':
-    fprintf(outfile,"void main_ipass(void)\n");
+    fprintf(outfile,"void main_ipass(ENGINE_PTR_DECLARE)\n");
     break;
   case 'n':
-    fprintf(outfile,"void main_initpass(void)\n");
+    fprintf(outfile,"void main_initpass(ENGINE_PTR_DECLARE)\n");
     break;
   default:
     internalerror("writemain.c","makeloops switch 1");
   }
 
-  fprintf(outfile,"\n{\n\n");
+  fprintf(outfile,"\n{\n");
 
   if (c == 'i')
-    fprintf(outfile,"int i;\n\n");
+    fprintf(outfile,"  int i;\n");
+
+  if (c == 'a')
+    fprintf(outfile,"  int busidx;\n");
+
+  /* functions that need sysidx */
+
+  if (((c == 'i') && (cin || session)) ||   /* makecontrolsys()     */
+      ((c == 'i') && csasl))                /* makesaslcontrolsys() */
+    found = 1;
+
+  if (!found)
+    {
+      sptr = instrnametable;
+      while ((sptr != NULL) && !found)
+	{      
+	  if (((sptr->startup) && (c == 'i')) ||  /* ipassstartup() */
+	      ((sptr->effects) && (c == 'i')))  /* ipasseffects() */
+	    found = 1;
+	  
+	  if ((((sptr->score) || (sptr->ascore))        /* sasl() */  ||
+	      (csasl || sptr->dyn || sptr->midi || sptr->amidi || 
+	       ((cmidi || session) && sptr->miditag))   /* core() */ ) 
+	      && ((c == 'i') || (c == 'k') || (c == 'a')))
+	    found = 1;
+
+	  sptr = sptr->next;
+	}
+    }
+
+  if (found)
+    fprintf(outfile,"  instr_line * sysidx;\n");
+
+  fprintf(outfile,"\n");
 
   if ((c == 'i') && (cin || session))
     makecontrolsys();
@@ -125,6 +158,7 @@ void makeloops(char c)
   if (c == 'a')
     makeinputbusread();
 
+  sptr = instrnametable;
   while (sptr != NULL)
     {      
       if (sptr->startup)  /* startup instanced at start of execution */
@@ -280,7 +314,7 @@ void makeloops(char c)
     makesaslcontrolsys();
 
   if (c == 'k')
-    fprintf(outfile, "\n  return graceful_exit;");
+    fprintf(outfile, "\n  return EV(graceful_exit);");
   if (c == 'n')
     makebufferinit();
       
@@ -305,7 +339,7 @@ void ipassstartup(sigsym * sptr)
 {
   if (sptr->cref->conlines)
     {
-      fprintf(outfile,"  sysidx = &u_startup[0];\n");
+      fprintf(outfile,"  sysidx = &EV(u_startup)[0];\n");
       fprintf(outfile,"  if (sysidx->noteon == PLAYING) {\n");
       fprintf(outfile,"   if (sysidx->released)\n");
       fprintf(outfile,"    {\n");
@@ -319,7 +353,7 @@ void ipassstartup(sigsym * sptr)
       fprintf(outfile,"      }\n");
       fprintf(outfile,"     else\n");
       fprintf(outfile,"      {\n");
-      fprintf(outfile,"        sysidx->abstime -= KTIME;\n");
+      fprintf(outfile,"        sysidx->abstime -= EV(KTIME);\n");
       fprintf(outfile,"        if (sysidx->abstime < 0.0F)\n");
       fprintf(outfile,"         {\n");
       fprintf(outfile,"           sysidx->noteon = ALLDONE;\n");
@@ -341,21 +375,21 @@ void ipassstartup(sigsym * sptr)
       fprintf(outfile,"      }\n");
       fprintf(outfile,"     else\n");
       fprintf(outfile,"      {\n");
-      fprintf(outfile,"        if (sysidx->endtime <= scorebeats)\n");
+      fprintf(outfile,"        if (sysidx->endtime <= EV(scorebeats))\n");
       fprintf(outfile,"         {\n");
       fprintf(outfile,"           if (sysidx->abstime <= 0.0F)\n");
       fprintf(outfile,"             sysidx->turnoff = sysidx->released = 1;\n");
       fprintf(outfile,"           else\n");
       fprintf(outfile,"           {\n");
-      fprintf(outfile,"             sysidx->abstime -= KTIME;\n");
+      fprintf(outfile,"             sysidx->abstime -= EV(KTIME);\n");
       fprintf(outfile,"             if (sysidx->abstime < 0.0F)\n");
       fprintf(outfile,"               sysidx->turnoff = sysidx->released = 1;\n");
       fprintf(outfile,"           }\n");
       fprintf(outfile,"         }\n");
       fprintf(outfile,"        else\n");
       fprintf(outfile,"          if ((sysidx->abstime < 0.0F) &&\n");  
-      fprintf(outfile,"           (1.666667e-2F*tempo*sysidx->abstime + \n");
-      fprintf(outfile,"               sysidx->endtime <= scorebeats))\n");
+      fprintf(outfile,"           (1.666667e-2F*EV(tempo)*sysidx->abstime + \n");
+      fprintf(outfile,"               sysidx->endtime <= EV(scorebeats)))\n");
       fprintf(outfile,"            sysidx->turnoff = sysidx->released = 1;\n");
       fprintf(outfile,"      }\n");
       fprintf(outfile,"    }\n");
@@ -372,11 +406,11 @@ void kpassstartup(sigsym * sptr)
 
 {
   if (sptr->cref->conlines)
-    fprintf(outfile,"  if (u_startup[0].noteon == PLAYING)\n");
+    fprintf(outfile,"  if (EV(u_startup)[0].noteon == PLAYING)\n");
   
   /* needs separate copy for u_startup to eliminate argument */
   
-  fprintf(outfile,"   startup_kpass(&ninstr[0]);\n");
+  fprintf(outfile,"   startup_kpass(ENGINE_PTR_COMMA &(EV(ninstr)[0]));\n");
   
 }
 
@@ -391,11 +425,11 @@ void apassstartup(sigsym * sptr)
   if (sptr->cref->alines)
     {
       if (sptr->cref->conlines)
-	fprintf(outfile,"  if (u_startup[0].noteon == PLAYING)\n");
+	fprintf(outfile,"  if (EV(u_startup)[0].noteon == PLAYING)\n");
 
       /* needs separate copy for u_startup to eliminate argument */
 
-      fprintf(outfile,"   startup_apass(&ninstr[0]);\n");
+      fprintf(outfile,"   startup_apass(ENGINE_PTR_COMMA &(EV(ninstr)[0]));\n");
     }
 }
 
@@ -421,13 +455,13 @@ void ipasssasl(sigsym * sptr, char c, char * prefix)
   if ( ((c == 's') && (sptr->score > 1)) ||
        ((c == 'a') && (sptr->ascore > 1)))
     {
-      fprintf(outfile,"  beginflag = 0;\n");
-      fprintf(outfile," for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+      fprintf(outfile,"  EV(beginflag) = 0;\n");
+      fprintf(outfile," for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 	      ,prefix,val,prefix,val);
       fprintf(outfile,"  {\n");
     }
   else
-    fprintf(outfile,"  sysidx = &%s_%s[0];\n", prefix, sptr->val);
+    fprintf(outfile,"  sysidx = &EV(%s_%s)[0];\n", prefix, sptr->val);
 
   fprintf(outfile,"  switch(sysidx->noteon) {\n");
   fprintf(outfile,"   case PLAYING:\n");
@@ -443,7 +477,7 @@ void ipasssasl(sigsym * sptr, char c, char * prefix)
   fprintf(outfile,"      }\n");
   fprintf(outfile,"     else\n");
   fprintf(outfile,"      {\n");
-  fprintf(outfile,"        sysidx->abstime -= KTIME;\n");
+  fprintf(outfile,"        sysidx->abstime -= EV(KTIME);\n");
   fprintf(outfile,"        if (sysidx->abstime < 0.0F)\n");
   fprintf(outfile,"         {\n");
   fprintf(outfile,"           sysidx->noteon = ALLDONE;\n");
@@ -464,57 +498,57 @@ void ipasssasl(sigsym * sptr, char c, char * prefix)
   fprintf(outfile,"      }\n");
   fprintf(outfile,"     else\n");
   fprintf(outfile,"      {\n");
-  fprintf(outfile,"        if (sysidx->endtime <= scorebeats)\n");
+  fprintf(outfile,"        if (sysidx->endtime <= EV(scorebeats))\n");
   fprintf(outfile,"         {\n");
   fprintf(outfile,"           if (sysidx->abstime <= 0.0F)\n");
   fprintf(outfile,"             sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"           else\n");
   fprintf(outfile,"           {\n");
-  fprintf(outfile,"             sysidx->abstime -= KTIME;\n");
+  fprintf(outfile,"             sysidx->abstime -= EV(KTIME);\n");
   fprintf(outfile,"             if (sysidx->abstime < 0.0F)\n");
   fprintf(outfile,"               sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"           }\n");
   fprintf(outfile,"         }\n");
   fprintf(outfile,"        else\n");  
   fprintf(outfile,"          if ((sysidx->abstime < 0.0F) &&\n");  
-  fprintf(outfile,"           (1.666667e-2F*tempo*sysidx->abstime + \n");
-  fprintf(outfile,"               sysidx->endtime <= scorebeats))\n");
+  fprintf(outfile,"           (1.666667e-2F*EV(tempo)*sysidx->abstime + \n");
+  fprintf(outfile,"               sysidx->endtime <= EV(scorebeats)))\n");
   fprintf(outfile,"            sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"      }\n");
   fprintf(outfile,"    }\n");
   fprintf(outfile,"   break;\n");
   fprintf(outfile,"   case TOBEPLAYED:\n");  
   if (c == 'a')
-    fprintf(outfile,"    if (sysidx->startabs <= absolutetime)\n");
+    fprintf(outfile,"    if (sysidx->startabs <= EV(absolutetime))\n");
   else
-    fprintf(outfile,"    if (sysidx->starttime <= scorebeats)\n");
+    fprintf(outfile,"    if (sysidx->starttime <= EV(scorebeats))\n");
   fprintf(outfile,"     {\n");
   fprintf(outfile,"      sysidx->noteon = PLAYING;\n");
-  fprintf(outfile,"      sysidx->notestate = nextstate;\n");
-  fprintf(outfile,"      sysidx->nstate = &ninstr[nextstate];\n");
+  fprintf(outfile,"      sysidx->notestate = EV(nextstate);\n");
+  fprintf(outfile,"      sysidx->nstate = &(EV(ninstr)[EV(nextstate)]);\n");
 
   if (totmidichan)
     {  
-      fprintf(outfile,"      sysidx->numchan = midimasterchannel;\n");
+      fprintf(outfile,"      sysidx->numchan = EV(midimasterchannel);\n");
     }
 
   fprintf(outfile,"      if (sysidx->sdur >= 0.0F)\n");
-  fprintf(outfile,"        sysidx->endtime = scorebeats + sysidx->sdur;\n");
-  fprintf(outfile,"      sysidx->kbirth = kcycleidx;\n");
-  fprintf(outfile,"      ninstr[nextstate].iline = sysidx;\n");
-  fprintf(outfile,"      sysidx->time = (kcycleidx-1)*KTIME;\n");
+  fprintf(outfile,"        sysidx->endtime = EV(scorebeats) + sysidx->sdur;\n");
+  fprintf(outfile,"      sysidx->kbirth = EV(kcycleidx);\n");
+  fprintf(outfile,"      EV(ninstr)[EV(nextstate)].iline = sysidx;\n");
+  fprintf(outfile,"      sysidx->time = (EV(kcycleidx)-1)*EV(KTIME);\n");
   nextstateupdate(NULL);
-  fprintf(outfile,"      %s_ipass(sysidx->nstate);\n",sptr->val);
+  fprintf(outfile,"      %s_ipass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
   fprintf(outfile,"    }\n");
   fprintf(outfile,"   break;\n");
   fprintf(outfile,"   }\n");
   if ( ((c == 's') && (sptr->score > 1)) ||
        ((c == 'a') && (sptr->ascore > 1)))
     {
-      fprintf(outfile,"   if ((!beginflag) && (sysidx->noteon == ALLDONE))\n");
-      fprintf(outfile,"     %s_%sfirst = sysidx+1;\n",prefix,val);
+      fprintf(outfile,"   if ((!EV(beginflag)) && (sysidx->noteon == ALLDONE))\n");
+      fprintf(outfile,"     EV(%s_%sfirst) = sysidx+1;\n",prefix,val);
       fprintf(outfile,"   else\n");
-      fprintf(outfile,"     beginflag = 1;\n");
+      fprintf(outfile,"     EV(beginflag) = 1;\n");
       fprintf(outfile," }\n");
     }
 
@@ -535,17 +569,17 @@ void kpasssasl(sigsym * sptr, char c, char * prefix)
   if ( ((c == 's') && (sptr->score == 1)) ||
        ((c == 'a') && (sptr->ascore == 1)))
     {
-      fprintf(outfile,"  if (%s_%s[0].noteon == PLAYING)\n", prefix, 
+      fprintf(outfile,"  if (EV(%s_%s)[0].noteon == PLAYING)\n", prefix, 
 	      sptr->val);
-      fprintf(outfile,"   %s_kpass(%s_%s[0].nstate);\n",sptr->val,
+      fprintf(outfile,"   %s_kpass(ENGINE_PTR_COMMA EV(%s_%s)[0].nstate);\n",sptr->val,
 	      prefix, sptr->val);
     }
   else
     {
-      fprintf(outfile," for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+      fprintf(outfile," for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 	      ,prefix,val,prefix,val);
       fprintf(outfile,"  if (sysidx->noteon == PLAYING)\n");
-      fprintf(outfile,"   %s_kpass(sysidx->nstate);\n",sptr->val);
+      fprintf(outfile,"   %s_kpass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
     }
   
   free(val);
@@ -568,18 +602,18 @@ void apasssasl(sigsym * sptr, char c, char * prefix)
       if ( ((c == 's') && (sptr->score == 1)) ||
 	   ((c == 'a') && (sptr->ascore == 1)))
 	{
-	  fprintf(outfile,"  if (%s_%s[0].noteon == PLAYING)\n", 
+	  fprintf(outfile,"  if (EV(%s_%s)[0].noteon == PLAYING)\n", 
 		  prefix, sptr->val);
-	  fprintf(outfile,"   %s_apass(%s_%s[0].nstate);\n",sptr->val,
+	  fprintf(outfile,"   %s_apass(ENGINE_PTR_COMMA EV(%s_%s)[0].nstate);\n",sptr->val,
 		  prefix, sptr->val);
 	}
       else
 	{
 	  fprintf(outfile,
-		  " for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+		  " for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 		  ,prefix, val,prefix,val);
 	  fprintf(outfile,"  if (sysidx->noteon == PLAYING)\n");
-	  fprintf(outfile,"   %s_apass(sysidx->nstate);\n",sptr->val);
+	  fprintf(outfile,"   %s_apass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
 	}
     }
   free(val);
@@ -606,14 +640,14 @@ void ipasscounter(sigsym * sptr, char c, char * s)
 
   val = dupunderscore(sptr->val);
 
-  fprintf(outfile,"    sysidx = %s_%slast;\n",s,val);
-  fprintf(outfile,"    while ((sysidx <= %s_%send) && \n",s,val);
+  fprintf(outfile,"    sysidx = EV(%s_%slast);\n",s,val);
+  fprintf(outfile,"    while ((sysidx <= EV(%s_%send)) && \n",s,val);
   if (c == 'a')
-    fprintf(outfile,"      (sysidx->startabs <= absolutetime))\n");
+    fprintf(outfile,"      (sysidx->startabs <= EV(absolutetime)))\n");
   else
-    fprintf(outfile,"      (sysidx->starttime <= scorebeats))\n");
+    fprintf(outfile,"      (sysidx->starttime <= EV(scorebeats)))\n");
   fprintf(outfile,"      {\n");
-  fprintf(outfile,"       %s_%slast = sysidx;\n",s,val);
+  fprintf(outfile,"       EV(%s_%slast) = sysidx;\n",s,val);
   fprintf(outfile,"       sysidx++;\n");
   fprintf(outfile,"      }\n");
 
@@ -632,8 +666,8 @@ void ipasscore(sigsym * sptr, char c, char * s)
   val = dupunderscore(sptr->val);
 
   if ((c != 'd') && (c != 'c') && (c != 'l'))
-    fprintf(outfile,"  beginflag = 0;\n");
-  fprintf(outfile," for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+    fprintf(outfile,"  EV(beginflag) = 0;\n");
+  fprintf(outfile," for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 	  ,s,val,s,val);
   fprintf(outfile,"  {\n");
   fprintf(outfile,"  switch(sysidx->noteon) {\n");
@@ -650,7 +684,7 @@ void ipasscore(sigsym * sptr, char c, char * s)
   fprintf(outfile,"      }\n");
   fprintf(outfile,"     else\n");
   fprintf(outfile,"      {\n");
-  fprintf(outfile,"        sysidx->abstime -= KTIME;\n");
+  fprintf(outfile,"        sysidx->abstime -= EV(KTIME);\n");
   fprintf(outfile,"        if (sysidx->abstime < 0.0F)\n");
   fprintf(outfile,"         {\n");
   fprintf(outfile,"           sysidx->noteon = ALLDONE;\n"); 
@@ -674,9 +708,9 @@ void ipasscore(sigsym * sptr, char c, char * s)
   if ((c == 'a')||(c == 'm')||(c == 'c'))
     {
       if (c == 'a')
-	fprintf(outfile,"        if ((sysidx->endabs <= absolutetime) &&\n");
+	fprintf(outfile,"        if ((sysidx->endabs <= EV(absolutetime)) &&\n");
       else
-	fprintf(outfile,"        if ((sysidx->endtime <= scorebeats) &&\n");
+	fprintf(outfile,"        if ((sysidx->endtime <= EV(scorebeats)) &&\n");
       fprintf(outfile,"        ");
 
       if (((c == 'm')||(c == 'a')) && midiallsoundsoff)
@@ -693,14 +727,14 @@ void ipasscore(sigsym * sptr, char c, char * s)
       fprintf(outfile,"\n");
     }
   else
-    fprintf(outfile,"        if (sysidx->endtime <= scorebeats)\n");
+    fprintf(outfile,"        if (sysidx->endtime <= EV(scorebeats))\n");
 
   fprintf(outfile,"         {\n");
   fprintf(outfile,"           if (sysidx->abstime <= 0.0F)\n");
   fprintf(outfile,"             sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"           else\n");
   fprintf(outfile,"           {\n");
-  fprintf(outfile,"             sysidx->abstime -= KTIME;\n");
+  fprintf(outfile,"             sysidx->abstime -= EV(KTIME);\n");
   fprintf(outfile,"             if (sysidx->abstime < 0.0F)\n");
   fprintf(outfile,"               sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"           }\n");
@@ -723,13 +757,13 @@ void ipasscore(sigsym * sptr, char c, char * s)
     {
       fprintf(outfile,"          if ((sysidx->abstime < 0.0F) &&\n");  
       fprintf(outfile,"           (sysidx->abstime + sysidx->endabs\n");
-      fprintf(outfile,"               <= absolutetime))\n");
+      fprintf(outfile,"               <= EV(absolutetime)))\n");
     }
   else
     {
       fprintf(outfile,"          if ((sysidx->abstime < 0.0F) &&\n");  
-      fprintf(outfile,"           (1.666667e-2F*tempo*sysidx->abstime + \n");
-      fprintf(outfile,"               sysidx->endtime <= scorebeats))\n");
+      fprintf(outfile,"           (1.666667e-2F*EV(tempo)*sysidx->abstime + \n");
+      fprintf(outfile,"               sysidx->endtime <= EV(scorebeats)))\n");
     }
   fprintf(outfile,"            sysidx->turnoff = sysidx->released = 1;\n");
   fprintf(outfile,"      }\n");
@@ -737,31 +771,31 @@ void ipasscore(sigsym * sptr, char c, char * s)
   fprintf(outfile,"   break;\n");
   fprintf(outfile,"   case TOBEPLAYED:\n");
   if (c == 'a')
-    fprintf(outfile,"    if (sysidx->startabs <= absolutetime)\n");
+    fprintf(outfile,"    if (sysidx->startabs <= EV(absolutetime))\n");
   else
-    fprintf(outfile,"    if (sysidx->starttime <= scorebeats)\n");
+    fprintf(outfile,"    if (sysidx->starttime <= EV(scorebeats))\n");
   fprintf(outfile,"     {\n");
   fprintf(outfile,"      sysidx->noteon = PLAYING;\n");
-  fprintf(outfile,"      sysidx->notestate = nextstate;\n");
-  fprintf(outfile,"      sysidx->nstate = &ninstr[nextstate];\n");
+  fprintf(outfile,"      sysidx->notestate = EV(nextstate);\n");
+  fprintf(outfile,"      sysidx->nstate = &(EV(ninstr)[EV(nextstate)]);\n");
 
   if (totmidichan && ((c == 'd') || (c == 'l')))
-    fprintf(outfile,"      sysidx->numchan = midimasterchannel;\n");
+    fprintf(outfile,"      sysidx->numchan = EV(midimasterchannel);\n");
 
   fprintf(outfile,"      if (sysidx->sdur >= 0.0F)\n");
-  fprintf(outfile,"        sysidx->endtime = scorebeats + sysidx->sdur;\n");
-  fprintf(outfile,"      sysidx->kbirth = kcycleidx;\n");
-  fprintf(outfile,"      ninstr[nextstate].iline = sysidx;\n");
-  fprintf(outfile,"      sysidx->time = (kcycleidx-1)*KTIME;\n");
+  fprintf(outfile,"        sysidx->endtime = EV(scorebeats) + sysidx->sdur;\n");
+  fprintf(outfile,"      sysidx->kbirth = EV(kcycleidx);\n");
+  fprintf(outfile,"      EV(ninstr)[EV(nextstate)].iline = sysidx;\n");
+  fprintf(outfile,"      sysidx->time = (EV(kcycleidx)-1)*EV(KTIME);\n");
   nextstateupdate(NULL);
-  fprintf(outfile,"      %s_ipass(sysidx->nstate);\n",sptr->val);
+  fprintf(outfile,"      %s_ipass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
   fprintf(outfile,"    }\n");
   fprintf(outfile,"   break;\n");
   if (c == 'd')
     {
       fprintf(outfile,"   case PAUSED:\n");
       fprintf(outfile,"      sysidx->noteon = PLAYING;\n");
-      fprintf(outfile,"      sysidx->kbirth = kcycleidx;\n");
+      fprintf(outfile,"      sysidx->kbirth = EV(kcycleidx);\n");
       fprintf(outfile,"   break;\n");
     }
   fprintf(outfile,"   default:\n");
@@ -769,25 +803,25 @@ void ipasscore(sigsym * sptr, char c, char * s)
   fprintf(outfile,"   }\n");
   if ((c != 'd')&&(c != 'c')&&(c != 'l'))
     {
-      fprintf(outfile,"   if ((!beginflag) && (sysidx->noteon == ALLDONE))\n");
-      fprintf(outfile,"     %s_%sfirst = sysidx+1;\n",s,val);
+      fprintf(outfile,"   if ((!EV(beginflag)) && (sysidx->noteon == ALLDONE))\n");
+      fprintf(outfile,"     EV(%s_%sfirst) = sysidx+1;\n",s,val);
       fprintf(outfile,"   else\n");
-      fprintf(outfile,"     beginflag = 1;\n");
+      fprintf(outfile,"     EV(beginflag) = 1;\n");
     }
   fprintf(outfile," }\n");
   if ((c == 'd')||(c == 'c')||(c == 'l'))
     {
-      fprintf(outfile,"  while (%s_%slast->noteon == ALLDONE)\n",s,val);
-      fprintf(outfile,"   if (%s_%slast == %s_%sfirst)\n",s,val,s,val);
+      fprintf(outfile,"  while (EV(%s_%slast)->noteon == ALLDONE)\n",s,val);
+      fprintf(outfile,"   if (EV(%s_%slast) == EV(%s_%sfirst))\n",s,val,s,val);
       fprintf(outfile,"    {\n");
-      fprintf(outfile,"     %s_%sfirst = &%s_%s[1];\n",s,val,s,sptr->val);
-      fprintf(outfile,"     %s_%slast =  &%s_%s[0];\n",s,val,s,sptr->val);
-      fprintf(outfile,"     %s_%snext =  NULL;\n",s,val);
-      fprintf(outfile,"     %s_%slast->noteon = TOBEPLAYED;\n",s,val);
+      fprintf(outfile,"     EV(%s_%sfirst) = &EV(%s_%s)[1];\n",s,val,s,sptr->val);
+      fprintf(outfile,"     EV(%s_%slast) =  &EV(%s_%s)[0];\n",s,val,s,sptr->val);
+      fprintf(outfile,"     EV(%s_%snext) =  NULL;\n",s,val);
+      fprintf(outfile,"     EV(%s_%slast)->noteon = TOBEPLAYED;\n",s,val);
       fprintf(outfile,"     break;\n");
       fprintf(outfile,"    }\n");
       fprintf(outfile,"   else\n");
-      fprintf(outfile,"    %s_%slast--;\n",s,val);
+      fprintf(outfile,"    EV(%s_%slast)--;\n",s,val);
     }
 
   free(val);
@@ -804,13 +838,13 @@ void kpasscore(sigsym * sptr, char c, char * s)
 
   val = dupunderscore(sptr->val);
 
-  fprintf(outfile," for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+  fprintf(outfile," for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 	  ,s,val,s,val);
   fprintf(outfile,"  if (sysidx->noteon == PLAYING)\n");
   fprintf(outfile,"  {\n");
   if (c == 'd')
     fprintf(outfile,"   sysidx->launch = LAUNCHED;\n");
-  fprintf(outfile,"   %s_kpass(sysidx->nstate);\n",sptr->val);
+  fprintf(outfile,"   %s_kpass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
   fprintf(outfile,"  }\n");
  
   free(val);
@@ -830,7 +864,7 @@ void apasscore(sigsym * sptr, char c, char * s)
   if (sptr->cref->alines)
     {
 
-      fprintf(outfile," for (sysidx=%s_%sfirst;sysidx<=%s_%slast;sysidx++)\n"
+      fprintf(outfile," for (sysidx=EV(%s_%sfirst);sysidx<=EV(%s_%slast);sysidx++)\n"
 	      ,s,val,s,val);
       if (c == 'd')
 	{
@@ -840,7 +874,7 @@ void apasscore(sigsym * sptr, char c, char * s)
       else
 	fprintf(outfile,"  if (sysidx->noteon == PLAYING)\n");
 
-      fprintf(outfile,"   %s_apass(sysidx->nstate);\n",sptr->val);
+      fprintf(outfile,"   %s_apass(ENGINE_PTR_COMMA sysidx->nstate);\n",sptr->val);
 
     }
   free(val);
@@ -932,15 +966,15 @@ void ipassinitpass(sigsym * sptr)
     {
       if (!strcmp(tptr->sptr->val, sptr->val))
 	{
-	  fprintf(outfile,"  e_%s[%i].noteon = PLAYING;\n", sptr->val,i);
-	  fprintf(outfile,"  e_%s[%i].notestate = nextstate;\n", sptr->val,i);
-	  fprintf(outfile,"  e_%s[%i].endtime = MAXENDTIME;\n", sptr->val,i);
-	  fprintf(outfile,"  e_%s[%i].nstate = &ninstr[nextstate];\n",
+	  fprintf(outfile,"  EV(e_%s)[%i].noteon = PLAYING;\n", sptr->val,i);
+	  fprintf(outfile,"  EV(e_%s)[%i].notestate = EV(nextstate);\n", sptr->val,i);
+	  fprintf(outfile,"  EV(e_%s)[%i].endtime = MAXENDTIME;\n", sptr->val,i);
+	  fprintf(outfile,"  EV(e_%s)[%i].nstate = &(EV(ninstr)[EV(nextstate)]);\n",
 		  sptr->val,i);
-	  fprintf(outfile,"  ninstr[nextstate].iline = &e_%s[%i];\n",
+	  fprintf(outfile,"  EV(ninstr)[EV(nextstate)].iline = &EV(e_%s)[%i];\n",
 		  sptr->val,i);
 	  nextstateupdate(NULL);
-	  fprintf(outfile,"   %s_ipass();\n", tptr->val);
+	  fprintf(outfile,"   %s_ipass(ENGINE_PTR);\n", tptr->val);
 	  fprintf(outfile,"\n");
 	  i++;
 	}
@@ -966,7 +1000,7 @@ void ipasseffects(sigsym * sptr)
 	{
 	  if (tptr->sptr->cref->conlines)
 	    {
-	      fprintf(outfile,"  sysidx = &e_%s[%i];\n", sptr->val,i);
+	      fprintf(outfile,"  sysidx = &EV(e_%s)[%i];\n", sptr->val,i);
 	      fprintf(outfile,"  if (sysidx->noteon == PLAYING) {\n");
 	      fprintf(outfile,"   if (sysidx->released)\n");
 	      fprintf(outfile,"    {\n");
@@ -977,7 +1011,7 @@ void ipasseffects(sigsym * sptr)
 	      fprintf(outfile,"      }\n");
 	      fprintf(outfile,"     else\n");
 	      fprintf(outfile,"      {\n");
-	      fprintf(outfile,"        sysidx->abstime -= KTIME;\n");
+	      fprintf(outfile,"        sysidx->abstime -= EV(KTIME);\n");
 	      fprintf(outfile,"        if (sysidx->abstime < 0.0F)\n");
 	      fprintf(outfile,"         {\n");
 	      fprintf(outfile,"           sysidx->noteon = ALLDONE;\n"); 
@@ -995,21 +1029,21 @@ void ipasseffects(sigsym * sptr)
 	      fprintf(outfile,"      }\n");
 	      fprintf(outfile,"     else\n");
 	      fprintf(outfile,"      {\n");
-	      fprintf(outfile,"        if (sysidx->endtime <= scorebeats)\n");
+	      fprintf(outfile,"        if (sysidx->endtime <= EV(scorebeats))\n");
 	      fprintf(outfile,"         {\n");
 	      fprintf(outfile,"           if (sysidx->abstime <= 0.0F)\n");
 	      fprintf(outfile,"             sysidx->turnoff = sysidx->released = 1;\n");
 	      fprintf(outfile,"           else\n");
 	      fprintf(outfile,"           {\n");
-	      fprintf(outfile,"             sysidx->abstime -= KTIME;\n");
+	      fprintf(outfile,"             sysidx->abstime -= EV(KTIME);\n");
 	      fprintf(outfile,"             if (sysidx->abstime < 0.0F)\n");
 	      fprintf(outfile,"               sysidx->turnoff = sysidx->released = 1;\n");
 	      fprintf(outfile,"           }\n");
 	      fprintf(outfile,"         }\n");
 	      fprintf(outfile,"        else\n");
 	      fprintf(outfile,"          if ((sysidx->abstime < 0.0F) &&\n");  
-	      fprintf(outfile,"           (1.666667e-2F*tempo*sysidx->abstime + \n");
-	      fprintf(outfile,"               sysidx->endtime <= scorebeats))\n");
+	      fprintf(outfile,"           (1.666667e-2F*EV(tempo)*sysidx->abstime + \n");
+	      fprintf(outfile,"               sysidx->endtime <= EV(scorebeats)))\n");
 	      fprintf(outfile,"            sysidx->turnoff = sysidx->released = 1;\n");
 	      fprintf(outfile,"      }\n");
 	      fprintf(outfile,"    }\n");
@@ -1038,9 +1072,9 @@ void kpasseffects(sigsym * sptr)
       if (!strcmp(tptr->sptr->val, sptr->val))
 	{
 	  if (tptr->sptr->cref->conlines)
-	    fprintf(outfile,"  if (e_%s[%i].noteon == PLAYING)\n",
+	    fprintf(outfile,"  if (EV(e_%s)[%i].noteon == PLAYING)\n",
 		    sptr->val,i);
-	  fprintf(outfile,"   %s_kpass();\n", tptr->val);
+	  fprintf(outfile,"   %s_kpass(ENGINE_PTR);\n", tptr->val);
 	  i++;
 	}
       tptr = tptr->next;
@@ -1066,9 +1100,9 @@ void apasseffects(sigsym * sptr)
 	  if (tptr->sptr->cref->alines)
 	    {
 	      if (tptr->sptr->cref->conlines)
-		fprintf(outfile,"  if (e_%s[%i].noteon == PLAYING)\n",
+		fprintf(outfile,"  if (EV(e_%s)[%i].noteon == PLAYING)\n",
 			sptr->val,i);
-	      fprintf(outfile,"   %s_apass();\n", tptr->val);
+	      fprintf(outfile,"   %s_apass(ENGINE_PTR);\n", tptr->val);
 	    }
 	  i++;
 	}
@@ -1094,32 +1128,32 @@ void makeinputbusread(void)
   if ((getvsym(&busnametable,"input_bus") != NULL) && (inchannels > 0) && 
       (ainflow == PASSIVE_FLOW) && (aoutflow == PASSIVE_FLOW))
     {
-      fprintf(outfile,"   if (ibusidx < asys_isize)\n");
+      fprintf(outfile,"   if (EV(ibusidx) < EV(asys_isize))\n");
       fprintf(outfile,
 	      "    for(busidx=BUS_input_bus;busidx<BUS_input_bus+%i;busidx++)\n",
 	      inchannels);
       switch (makeaudiotypein(ain)) {
       case SAMPLE_SHORT:
 	fprintf(outfile,
-		"      TB(busidx) = 3.051851e-5F*asys_ibuf[ibusidx++];\n");
+		"      TB(busidx) = 3.051851e-5F*EV(asys_ibuf)[EV(ibusidx)++];\n");
 	break;
       case SAMPLE_FLOAT:
 	fprintf(outfile,
-		"      TB(busidx) = asys_ibuf[ibusidx++];\n");
+		"      TB(busidx) = EV(asys_ibuf)[EV(ibusidx)++];\n");
 	break;
       }
       fprintf(outfile,"   else\n");
       fprintf(outfile,"   {\n");
-      fprintf(outfile,"    ibusidx = 0;\n");
-      fprintf(outfile,"    if (asys_getbuf(&asys_ibuf, &asys_isize)"
-	                       "||(!asys_isize))\n");
+      fprintf(outfile,"    EV(ibusidx) = 0;\n");
+      fprintf(outfile,"    if (asys_getbuf(&EV(asys_ibuf), &EV(asys_isize))"
+	                       "||(!EV(asys_isize)))\n");
       fprintf(outfile,"     {\n");
-      fprintf(outfile,"       asys_isize = 0;\n");
+      fprintf(outfile,"       EV(asys_isize) = 0;\n");
       fprintf(outfile,
 	      "       for(busidx=BUS_input_bus;busidx<BUS_input_bus+%i;busidx++)\n",
 	      inchannels);
       fprintf(outfile,"       TB(busidx) = 0.0F;\n");
-      fprintf(outfile,"       kcycleidx = endkcycle;\n");
+      fprintf(outfile,"       EV(kcycleidx) = EV(endkcycle);\n");
       fprintf(outfile,"      }\n");
       fprintf(outfile,"    else\n");
       fprintf(outfile,
@@ -1128,11 +1162,11 @@ void makeinputbusread(void)
       switch (makeaudiotypein(ain)) {
       case SAMPLE_SHORT:
 	fprintf(outfile,
-		"      TB(busidx) = 3.051851e-5F*asys_ibuf[ibusidx++];\n");
+		"      TB(busidx) = 3.051851e-5F*EV(asys_ibuf)[EV(ibusidx)++];\n");
 	break;
       case SAMPLE_FLOAT:
 	fprintf(outfile,
-		"      TB(busidx) = asys_ibuf[ibusidx++];\n");
+		"      TB(busidx) = EV(asys_ibuf)[EV(ibusidx)++];\n");
 	break;
       }
       fprintf(outfile,"   }\n");
@@ -1161,14 +1195,14 @@ void makebufferinit(void)
 
   if (cin)
     {
-      fprintf(outfile, "   if (csys_setup() != CSYS_DONE)\n");
+      fprintf(outfile, "   if (csys_setup(ENGINE_PTR) != CSYS_DONE)\n");
       gened(NULL,"control input device unavailable");
       fprintf(outfile, "\n");
     }
 
   if ((ain == aout) && (iptr != NULL) && (inchannels > 0))
     {
-      fprintf(outfile, "   if (asys_iosetup((int)ARATE, ASYS_ICHAN, ");
+      fprintf(outfile, "   if (asys_iosetup((int) EV(ARATE), ASYS_ICHAN, ");
       fprintf(outfile, "ASYS_OCHAN, ASYS_ITYPENAME, ASYS_OTYPENAME,");
       fprintf(outfile, "\"%s\", \"%s\",", ainname, aoutname);
       fprintf(outfile, "ASYS_TIMEOPTION) != ASYS_DONE)\n");
@@ -1176,14 +1210,14 @@ void makebufferinit(void)
     }
   else
     {
-      fprintf(outfile, "   if (asys_osetup((int)ARATE, ASYS_OCHAN, ");
+      fprintf(outfile, "   if (asys_osetup((int) EV(ARATE), ASYS_OCHAN, ");
       fprintf(outfile, "ASYS_OTYPENAME, ");
       fprintf(outfile, " \"%s\",\n", aoutname);
       fprintf(outfile, "ASYS_TIMEOPTION) != ASYS_DONE)\n");
       gened(NULL,"audio output device unavailable");
       if ((iptr != NULL) && (inchannels > 0))
 	{
-	  fprintf(outfile, "   if (asys_isetup((int)ARATE, ASYS_ICHAN, ");
+	  fprintf(outfile, "   if (asys_isetup((int) EV(ARATE), ASYS_ICHAN, ");
 	  fprintf(outfile, "ASYS_ITYPENAME, ");
 	  fprintf(outfile, " \"%s\",", ainname);
 	  fprintf(outfile, "ASYS_TIMEOPTION) != ASYS_DONE)\n");
@@ -1193,20 +1227,20 @@ void makebufferinit(void)
 
   if (allsasl->endtimeval)
     {
-      fprintf(outfile, "   endkcycle = kbase + (int) \n");
+      fprintf(outfile, "   EV(endkcycle) = EV(kbase) + (int) \n");
       fprintf(outfile, 
-	      "      (KRATE*(endtime - scorebase)*(60.0F/tempo));\n\n");
+	      "      (EV(KRATE)*(EV(endtime) - EV(scorebase))*(60.0F/EV(tempo)));\n\n");
       if (abssasl->endtimeval)
 	{
 	  fprintf(outfile, 
-		  "   endkcycle = (endkinit > endkcycle) ?\n");
+		  "   EV(endkcycle) = (EV(endkinit) > EV(endkcycle)) ?\n");
 	  fprintf(outfile, 
-		  "                endkinit : endkcycle;\n\n");
+		  "                EV(endkinit) : EV(endkcycle);\n\n");
 	}
     }
   else
     {
-      fprintf(outfile, "   endkcycle = endkinit;\n\n");
+      fprintf(outfile, "   EV(endkcycle) = EV(endkinit);\n\n");
     }
 
   if ((ainflow == PASSIVE_FLOW) && (aoutflow == PASSIVE_FLOW))
@@ -1217,14 +1251,14 @@ void makebufferinit(void)
       if ((iptr != NULL) && (inchannels > 0))
 	{
 	  fprintf(outfile, " if "
-		  "((asys_getbuf(&asys_ibuf, &asys_isize) != ASYS_DONE)\n");
+		  "((asys_getbuf(&EV(asys_ibuf), &EV(asys_isize)) != ASYS_DONE)\n");
 	  fprintf(outfile,
-		  "     || (!asys_isize))\n");
+		  "     || (!EV(asys_isize)))\n");
 	  gened(NULL,"audio input device unavailable");
 	}
 
       fprintf(outfile, 
-	      "   if (asys_preamble(&asys_obuf, &asys_osize) != ASYS_DONE)\n");
+	      "   if (asys_preamble(&EV(asys_obuf), &EV(asys_osize)) != ASYS_DONE)\n");
       gened(NULL,"audio output device unavailable");
     }
 
