@@ -625,7 +625,7 @@ void wavegeneratorvar(sigsym * sptr)
   case 's':
     if (!(strcmp(ident->val,"sample")))
       {
-	z[lc++]="long %2$s_skip;";
+	z[lc++]="int %2$s_skip;";
 
 	sinfo = (sampleinfo *) 
 	  sptr->defnode->down->next->next->next->next->next->down->next->next->ibus;
@@ -783,30 +783,30 @@ void createtable(sigsym * ident, char * prefix, int mode)
       }
     if (startupinstr && (currinstrument == startupinstr))
       tablestartupcheck(ident, mode, K_IMPORT); 
-    z[lc++]= "i = NT(%1$s).len = gtables[TBL_GBL_%2$s].len;";
-    z[lc++]= "NT(%1$s).lenf = gtables[TBL_GBL_%2$s].lenf;";
-    z[lc++]= "NT(%1$s).start = gtables[TBL_GBL_%2$s].start;";
-    z[lc++]= "NT(%1$s).end = gtables[TBL_GBL_%2$s].end;";
-    z[lc++]= "NT(%1$s).base = gtables[TBL_GBL_%2$s].base;";
-    z[lc++]= "NT(%1$s).stamp = gtables[TBL_GBL_%2$s].stamp;";
-    z[lc++]= "NT(%1$s).sr = gtables[TBL_GBL_%2$s].sr;";
-    z[lc++]= "NT(%1$s).tend = gtables[TBL_GBL_%2$s].tend;";
-    z[lc++]= "NT(%1$s).oconst = gtables[TBL_GBL_%2$s].oconst;";
-    z[lc++]= "NT(%1$s).dint = gtables[TBL_GBL_%2$s].dint;";
-    z[lc++]= "NT(%1$s).dfrac = gtables[TBL_GBL_%2$s].dfrac;";
-    z[lc++]= "NT(%1$s).sffl = gtables[TBL_GBL_%2$s].sffl;";
-    z[lc++]= "NT(%1$s).sfui = gtables[TBL_GBL_%2$s].sfui;";
-    z[lc++]= "NT(%1$s).dsincr = gtables[TBL_GBL_%2$s].dsincr;";
+    z[lc++]= "i = NT(%1$s).len = EV(gtables)[TBL_GBL_%2$s].len;";
+    z[lc++]= "NT(%1$s).lenf = EV(gtables)[TBL_GBL_%2$s].lenf;";
+    z[lc++]= "NT(%1$s).start = EV(gtables)[TBL_GBL_%2$s].start;";
+    z[lc++]= "NT(%1$s).end = EV(gtables)[TBL_GBL_%2$s].end;";
+    z[lc++]= "NT(%1$s).base = EV(gtables)[TBL_GBL_%2$s].base;";
+    z[lc++]= "NT(%1$s).stamp = EV(gtables)[TBL_GBL_%2$s].stamp;";
+    z[lc++]= "NT(%1$s).sr = EV(gtables)[TBL_GBL_%2$s].sr;";
+    z[lc++]= "NT(%1$s).tend = EV(gtables)[TBL_GBL_%2$s].tend;";
+    z[lc++]= "NT(%1$s).oconst = EV(gtables)[TBL_GBL_%2$s].oconst;";
+    z[lc++]= "NT(%1$s).dint = EV(gtables)[TBL_GBL_%2$s].dint;";
+    z[lc++]= "NT(%1$s).dfrac = EV(gtables)[TBL_GBL_%2$s].dfrac;";
+    z[lc++]= "NT(%1$s).sffl = EV(gtables)[TBL_GBL_%2$s].sffl;";
+    z[lc++]= "NT(%1$s).sfui = EV(gtables)[TBL_GBL_%2$s].sfui;";
+    z[lc++]= "NT(%1$s).dsincr = EV(gtables)[TBL_GBL_%2$s].dsincr;";
     if ((ident->tref->assigntval == 0) &&
 	(gptr->tref->assigntval == 0))
       {
-	z[lc++]= "NT(%1$s).t = gtables[TBL_GBL_%2$s].t;";
+	z[lc++]= "NT(%1$s).t = EV(gtables)[TBL_GBL_%2$s].t;";
       }
     else
       {
 	z[lc++]= "NT(%1$s).t = (float *) malloc((i+1)*sizeof(float));";
 	z[lc++]= "for(;i >= 0;i--)";
-	z[lc++]= "  NT(%1$s).t[i] = gtables[TBL_GBL_%2$s].t[i];";
+	z[lc++]= "  NT(%1$s).t[i] = EV(gtables)[TBL_GBL_%2$s].t[i];";
 	z[lc++]= "NT(%1$s).llmem = 1;";
       }
     printwaveblock(lc,ident,prefix);
@@ -2421,9 +2421,9 @@ void tablepreamble(sigsym * ident, char * prefix, int mode, int action)
       z[lc++]= "NT(%1$s).dsincr = SINC_PILEN;";
     }
 
-  z[lc++]= "NT(%1$s).stamp = scorebeats;";
+  z[lc++]= "NT(%1$s).stamp = EV(scorebeats);";
   z[lc++]= "NT(%1$s).lenf = (float)(i);";
-  z[lc++]= "NT(%1$s).oconst = ATIME*((float)i);";
+  z[lc++]= "NT(%1$s).oconst = EV(ATIME)*((float)i);";
   z[lc++]= "if (i>0)";
   z[lc++]= "{";
   z[lc++]= "  NT(%1$s).tend = i - 1;";
@@ -2533,9 +2533,9 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
   tnode * sizeptr;
   tnode * fileptr;
   tnode * skipptr = NULL;
-  unsigned long size = 0;
+  unsigned int size = 0;
   int tsize = 0;
-  unsigned long skip = 0;
+  unsigned int skip = 0;
   int known, currblocksafe;
   char * lname = makewstring(ident->val);
   char * suffix;
@@ -2553,56 +2553,101 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
   /* set variables independent of size and skip  */
   /***********************************************/
 
-  z[lc++]= "NT(%1$s).stamp = scorebeats;";
+  z[lc++]= "NT(%1$s).stamp = EV(scorebeats);";
 
-  mz(lc); sprintf(z[lc++], "NT(%s_%s).sr = %li;", prefix, ident->val,
+  mz(lc); sprintf(z[lc++], "NT(%s_%s).sr = %i;", prefix, ident->val,
 		  sinfo->srate);
 
-  if (srate == sinfo->srate)
+  if (reentrant)
     {
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).dint = 1;", prefix, ident->val);
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).dfrac = 0;", prefix, ident->val);
+      mz(lc); sprintf(z[lc++], "if (EV(ARATE) == %u.0F)", sinfo->srate);
+      mz(lc); sprintf(z[lc++], "  {");
+      mz(lc); sprintf(z[lc++], "    NT(%s_%s).dint = 1;", prefix, ident->val);
+      mz(lc); sprintf(z[lc++], "    NT(%s_%s).dfrac = 0;", prefix, ident->val);
+      mz(lc); sprintf(z[lc++], "  }");
+      mz(lc); sprintf(z[lc++], "else");
+      mz(lc); sprintf(z[lc++], "  {");
+      mz(lc); sprintf(z[lc++], "     NT(%s_%s).dfrac = (unsigned int)"
+		      "(4294967296.0*((%u.0/EV(ARATE)) - ((int)(%u.0/EV(ARATE)))));",
+		      prefix, ident->val, sinfo->srate, sinfo->srate);
+      mz(lc); sprintf(z[lc++], "     NT(%s_%s).dint = (unsigned int)(%u.0/EV(ARATE));",
+		      prefix, ident->val, sinfo->srate);
+      mz(lc); sprintf(z[lc++], "  }");
     }
   else
     {
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).dfrac = %luUL;", prefix, ident->val,
-		      (unsigned long) (4294967296.0*
-				       modf(((double)sinfo->srate)/((double)srate), 
-					    &intdummy)));
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).dint = %luUL;", prefix, ident->val,
-		      (unsigned long) intdummy);
+      if (srate == sinfo->srate)
+	{
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).dint = 1;", prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).dfrac = 0;", prefix, ident->val);
+	}
+      else
+	{
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).dfrac = %uU;", prefix, ident->val,
+			  (unsigned int) (4294967296.0*
+					   modf(((double)sinfo->srate)/((double)srate), 
+						&intdummy)));
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).dint = %uU;", prefix, ident->val,
+			  (unsigned int) intdummy);
+	}
     }
 
   if (interp == INTERP_SINC)
     {
-      if (srate >= sinfo->srate)
+      if (reentrant)
 	{
-	  mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = 1.0F;", prefix, ident->val);
-	  mz(lc); sprintf(z[lc++], "NT(%s_%s).sfui = 0x00010000;", prefix, ident->val);
-	  mz(lc); sprintf(z[lc++], "NT(%s_%s).dsincr = SINC_PILEN;", prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "if (EV(ARATE) >= %u.0F)", sinfo->srate);
+	  mz(lc); sprintf(z[lc++], "  {");
+	  mz(lc); sprintf(z[lc++],    "NT(%s_%s).sffl = 1.0F;", prefix, ident->val);
+	  mz(lc); sprintf(z[lc++],    "NT(%s_%s).sfui = 0x00010000;", prefix, ident->val);
+	  mz(lc); sprintf(z[lc++],    "NT(%s_%s).dsincr = SINC_PILEN;", prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "  }");
+	  mz(lc); sprintf(z[lc++], "else");
+	  mz(lc); sprintf(z[lc++], "  {");
+	  mz(lc); sprintf(z[lc++], "   if (SINC_UPMAX*EV(ARATE) > %u.0F)", 
+			  sinfo->srate);
+	  mz(lc); sprintf(z[lc++], "     NT(%s_%s).sffl = (EV(ARATE)/NT(%s_%s).sr);", 
+			  prefix, ident->val, prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "   else");
+	  mz(lc); sprintf(z[lc++], "     NT(%s_%s).sffl = (1.0F/SINC_UPMAX);", 
+			  prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "   NT(%s_%s).sfui = ((float)(pow(2,16)))*NT(%s_%s).sffl + 0.5F;", 
+			  prefix, ident->val, prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "   NT(%s_%s).dsincr = (SINC_PILEN*NT(%s_%s).sfui) >> 16;", 
+			  prefix, ident->val, prefix, ident->val);
+	  mz(lc); sprintf(z[lc++], "  }");
 	}
       else
 	{
-	  if (srate*sinc_upmax > sinfo->srate)
+	  if (srate >= sinfo->srate)
 	    {
-	      mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = (ARATE/NT(%s_%s).sr);", 
-			      prefix, ident->val, prefix, ident->val);
+	      mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = 1.0F;", prefix, ident->val);
+	      mz(lc); sprintf(z[lc++], "NT(%s_%s).sfui = 0x00010000;", prefix, ident->val);
+	      mz(lc); sprintf(z[lc++], "NT(%s_%s).dsincr = SINC_PILEN;", prefix, ident->val);
 	    }
 	  else
 	    {
-	      mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = (1.0F/SINC_UPMAX);", 
-			      prefix, ident->val);
-	    }
-
-	  mz(lc); sprintf(z[lc++], 
-			  "NT(%s_%s).sfui = ((float)(pow(2,16)))*NT(%s_%s).sffl + 0.5F;", 
-			  prefix, ident->val, prefix, ident->val);
-	  mz(lc); sprintf(z[lc++], 
-			  "NT(%s_%s).dsincr = (SINC_PILEN*NT(%s_%s).sfui) >> 16;", 
-			  prefix, ident->val, prefix, ident->val);
+	      if (srate*sinc_upmax > sinfo->srate)
+		{
+		  mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = (EV(ARATE)/NT(%s_%s).sr);", 
+				  prefix, ident->val, prefix, ident->val);
+		}
+	      else
+		{
+		  mz(lc); sprintf(z[lc++], "NT(%s_%s).sffl = (1.0F/SINC_UPMAX);", 
+				  prefix, ident->val);
+		}
+	      
+	      mz(lc); sprintf(z[lc++], 
+			      "NT(%s_%s).sfui = ((float)(pow(2,16)))*NT(%s_%s).sffl + 0.5F;", 
+			      prefix, ident->val, prefix, ident->val);
+	      mz(lc); sprintf(z[lc++], 
+			      "NT(%s_%s).dsincr = (SINC_PILEN*NT(%s_%s).sfui) >> 16;", 
+			      prefix, ident->val, prefix, ident->val);
+	    }	
 	}
     }
-
+  
   if (sinfo->hasbase)
     {      
       mz(lc); sprintf(z[lc++], "NT(%s_%s).base = %s;", prefix, ident->val,
@@ -2611,11 +2656,11 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 
   if (sinfo->hasloop)
     {	  
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).start = %li;", 
+      mz(lc); sprintf(z[lc++], "NT(%s_%s).start = %i;", 
 		      prefix, ident->val, sinfo->start);
       if (sinfo->end)
 	{
-	  mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = NT(%s_%s).end = %li;", 
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = NT(%s_%s).end = %i;", 
 			  prefix, ident->val, prefix, ident->val, sinfo->end);
 	}
     }
@@ -2643,26 +2688,26 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	size = atoi(sizeptr->down->val);
 
       mz(lc); sprintf(z[lc++], 
-		      "NT(%s_%s).lenf = (float)(NT(%s_%s).len = %li);",
+		      "NT(%s_%s).lenf = (float)(NT(%s_%s).len = %i);",
 		      prefix,ident->val, prefix, ident->val, size);
 
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).oconst = NT(%s_%s).lenf*ATIME;",
+      mz(lc); sprintf(z[lc++], "NT(%s_%s).oconst = NT(%s_%s).lenf*EV(ATIME);",
 		      prefix,ident->val, prefix, ident->val);
 
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).t = (float *)(calloc(%li, %i));",
+      mz(lc); sprintf(z[lc++], "NT(%s_%s).t = (float *)(calloc(%i, %i));",
 		      prefix, ident->val, size + 1, (int)sizeof(float));
 
       if (sinfo->hasloop)
 	{	  
 	  if (!(sinfo->end))
 	    {
-	      mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = %li;",
+	      mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = %i;",
 			      prefix,ident->val, size - 1);
 	    }
 	}
       else
 	{
-	  mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = %li;",
+	  mz(lc); sprintf(z[lc++], "NT(%s_%s).tend = %i;",
 			  prefix,ident->val, size - 1);
 	}
     }
@@ -2678,7 +2723,7 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	  if (skipptr)
 	    skip = atoi(skipptr->down->val);
 
-	  mz(lc); sprintf(z[lc++], "%s_skip = %li;", lname, skip);
+	  mz(lc); sprintf(z[lc++], "%s_skip = %i;", lname, skip);
 	}
       else
 	{ 
@@ -2696,11 +2741,11 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 
       mz(lc); sprintf(z[lc++], 
 		      "NT(%s_%s).lenf = (float)(NT(%s_%s).len = "
-		      "((%s_size <= 0) ? (%li - %s_skip) : %s_size));",
+		      "((%s_size <= 0) ? (%i - %s_skip) : %s_size));",
 		      prefix, ident->val, prefix, ident->val, lname,
 		      sinfo->len, lname, lname);
 
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).oconst = NT(%s_%s).lenf*ATIME;",
+      mz(lc); sprintf(z[lc++], "NT(%s_%s).oconst = NT(%s_%s).lenf*EV(ATIME);",
 		      prefix,ident->val, prefix, ident->val);
 
       z[lc++]= "NT(%1$s).t = (float *)(calloc(NT(%1$s).len +1,";
@@ -2726,24 +2771,24 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
   if ((suffix = strrchr(fileptr->val, '.')) && (suffix = strrchr(suffix, '@')))
     suffix[0] = '\0';
 
-  mz(lc); sprintf(z[lc++], "sfile = fopen(\"%s\", \"rb\");", fileptr->val);
+  mz(lc); sprintf(z[lc++], "EV(sfile) = fopen(\"%s\", \"rb\");", fileptr->val);
 
   if (suffix)
     suffix[0] = '@';
 
-  z[lc++]= "if (sfile == NULL)";
+  z[lc++]= "if (EV(sfile) == NULL)";
   genex(&lc, ident->defnode->down, "Samplefile not found");
 
   if (known)
     {
       /* we don't fseek() to simplify signal handling for real-time */
 
-      mz(lc); sprintf(z[lc++], "for (i = 0; i < %li; i++)", 
+      mz(lc); sprintf(z[lc++], "for (i = 0; i < %i; i++)", 
 		      sinfo->point + skip*sinfo->framebytes);
-      z[lc++]= "if (!rread(%2$s_c,1,1,sfile))";
+      z[lc++]= "if (!rread(%2$s_c,1,1,EV(sfile)))";
       genex(&lc, ident->defnode->down, "Corrupt samplefile");
 
-      mz(lc); sprintf(z[lc++], "for (i=0; i < %li; i++)", 
+      mz(lc); sprintf(z[lc++], "for (i=0; i < %i; i++)", 
 		      tsize ? size : ((size < (sinfo->len - skip)) ? 
 				      size : (sinfo->len - skip)));  
       z[lc++]= "{";
@@ -2752,19 +2797,19 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
   else
     {
 
-      mz(lc); sprintf(z[lc++], "for (i = 0; i < %li + %i*%s_skip; i++)", 
+      mz(lc); sprintf(z[lc++], "for (i = 0; i < %i + %i*%s_skip; i++)", 
 		      sinfo->point, sinfo->framebytes, lname);
-      z[lc++]= "if (!rread(%2$s_c,1,1,sfile))";
+      z[lc++]= "if (!rread(%2$s_c,1,1,EV(sfile)))";
       genex(&lc, ident->defnode->down, "Corrupt samplefile");
 
       z[lc++]="for (i=0; i < NT(%1$s).len; i++)";
       z[lc++]= "{";
-      mz(lc); sprintf(z[lc++], "if (i >= (%li - %s_skip))", 
+      mz(lc); sprintf(z[lc++], "if (i >= (%i - %s_skip))", 
 		      sinfo->len, lname);
       z[lc++]="  break;";
     }
 
-  mz(lc); sprintf(z[lc++], "if (!rread(%s_c,1,%i,sfile))", 
+  mz(lc); sprintf(z[lc++], "if (!rread(%s_c,1,%i,EV(sfile)))", 
 		  lname, sinfo->framebytes);
   genex(&lc, ident->defnode->down, "Corrupt samplefile");
 
@@ -2775,18 +2820,18 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	  switch (sinfo->numbytes) {
 	  case 3:
 	    z[lc++]= "     NT(%1$s).t[i] = ((float)pow(2, -23))*(";
-	    mz(lc);  sprintf(z[lc++], "    ((long)(%s_c[%hhi])) + ", 
+	    mz(lc);  sprintf(z[lc++], "    ((int)(%s_c[%hhi])) + ", 
 			     lname, sinfo->chanpoint);
-	    mz(lc);  sprintf(z[lc++], "    (((long)(%s_c[%hhi])) << 8) +", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)(%s_c[%hhi])) << 8) +", 
 			     lname, sinfo->chanpoint + 1);
-	    mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 16));", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 16));", 
 			     lname, sinfo->chanpoint + 2);
 	    break;
 	  case 2:
 	    z[lc++]= "     NT(%1$s).t[i] = ((float)pow(2, -15))*(";
-	    mz(lc);  sprintf(z[lc++], "    ((long)(%s_c[%hhi])) + ", 
+	    mz(lc);  sprintf(z[lc++], "    ((int)(%s_c[%hhi])) + ", 
 			     lname, sinfo->chanpoint);
-	    mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 8));", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 8));", 
 			     lname, sinfo->chanpoint + 1);
 	    break;
 	  case 1:
@@ -2824,17 +2869,17 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	    {
 	      switch (sinfo->numbytes) {
 	      case 3:
-		mz(lc);  sprintf(z[lc++], "    %c ((long)(%s_c[%hhi])) + ", 
+		mz(lc);  sprintf(z[lc++], "    %c ((int)(%s_c[%hhi])) + ", 
 				 bytecount ? '+' : ' ', lname, bytecount);
-		mz(lc);  sprintf(z[lc++], "    (((long)(%s_c[%hhi])) << 8) +", 
+		mz(lc);  sprintf(z[lc++], "    (((int)(%s_c[%hhi])) << 8) +", 
 				 lname, bytecount + 1);
-		mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 16)", 
+		mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 16)", 
 				 lname, bytecount + 2);
 		break;
 	      case 2:
-		mz(lc);  sprintf(z[lc++], "    %c ((long)(%s_c[%hhi])) + ", 
+		mz(lc);  sprintf(z[lc++], "    %c ((int)(%s_c[%hhi])) + ", 
 				 bytecount ? '+' : ' ', lname, bytecount);
-		mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 8)", 
+		mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 8)", 
 				 lname, bytecount + 1);
 		break;
 	      case 1:
@@ -2854,18 +2899,18 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	  switch (sinfo->numbytes) {
 	  case 3:
 	    z[lc++]= "     NT(%1$s).t[i] = ((float)pow(2, -23))*(";
-	    mz(lc);  sprintf(z[lc++], "    ((long)(%s_c[%hhi])) + ", 
+	    mz(lc);  sprintf(z[lc++], "    ((int)(%s_c[%hhi])) + ", 
 			     lname, sinfo->chanpoint + 2);
-	    mz(lc);  sprintf(z[lc++], "    (((long)(%s_c[%hhi])) << 8) +", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)(%s_c[%hhi])) << 8) +", 
 			     lname, sinfo->chanpoint + 1);
-	    mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 16));", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 16));", 
 			     lname, sinfo->chanpoint);
 	    break;
 	  case 2:
 	    z[lc++]= "     NT(%1$s).t[i] = ((float)pow(2, -15))*(";
-	    mz(lc);  sprintf(z[lc++], "    ((long)(%s_c[%hhi])) + ", 
+	    mz(lc);  sprintf(z[lc++], "    ((int)(%s_c[%hhi])) + ", 
 			     lname, sinfo->chanpoint + 1);
-	    mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 8));", 
+	    mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 8));", 
 			     lname, sinfo->chanpoint);
 	    break;
 	  case 1:
@@ -2903,17 +2948,17 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 	    {
 	      switch (sinfo->numbytes) {
 	      case 3:
-		mz(lc);  sprintf(z[lc++], "    %c ((long)(%s_c[%hhi])) + ", 
+		mz(lc);  sprintf(z[lc++], "    %c ((int)(%s_c[%hhi])) + ", 
 				 bytecount ? '+': ' ', lname, bytecount + 2);
-		mz(lc);  sprintf(z[lc++], "    (((long)(%s_c[%hhi])) << 8) +", 
+		mz(lc);  sprintf(z[lc++], "    (((int)(%s_c[%hhi])) << 8) +", 
 				 lname, bytecount + 1);
-		mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 16)", 
+		mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 16)", 
 				 lname, bytecount);
 		break;
 	      case 2:
-		mz(lc);  sprintf(z[lc++], "    %c ((long)(%s_c[%hhi])) + ", 
+		mz(lc);  sprintf(z[lc++], "    %c ((int)(%s_c[%hhi])) + ", 
 				 bytecount ? '+': ' ', lname, bytecount + 1);
-		mz(lc);  sprintf(z[lc++], "    (((long)((char)(%s_c[%hhi]))) << 8)", 
+		mz(lc);  sprintf(z[lc++], "    (((int)((char)(%s_c[%hhi]))) << 8)", 
 				 lname, bytecount);
 		break;
 	      case 1:
@@ -2929,10 +2974,10 @@ void samplefilecode(sigsym * ident, char * prefix, int * lcptr)
 
   z[lc++]= "}";
 
-  z[lc++]= " fclose(sfile);";
+  z[lc++]= " fclose(EV(sfile));";
   if (known)
     {
-      mz(lc); sprintf(z[lc++], "NT(%s_%s).t[%li] = NT(%s_%s).t[0];",
+      mz(lc); sprintf(z[lc++], "NT(%s_%s).t[%i] = NT(%s_%s).t[0];",
 		      prefix, ident->val, size, prefix, ident->val);
     }
   else
@@ -2959,7 +3004,7 @@ void randomconstcode(sigsym * ident, char * prefix,
   tnode * p2ptr;
   int dist;
 
-  dist = (int) make_long(distptr->down);
+  dist = make_int(distptr->down);
 
   if ((dist < 1) || (dist > 5))
     {      
